@@ -30,11 +30,18 @@ freepops.MODULES_MAP["virgilio.it"]	= {
 	name="tin.lua",
 	args={folder="INBOX"}
 }
-
 freepops.MODULES_MAP["tin.it"]		= {
 	name="tin.lua",
 	args={folder="INBOX"}
 }
+freepops.MODULES_MAP["alice.it"]	= {
+	name="tin.lua",
+	args={folder="INBOX"}
+}
+freepops.MODULES_MAP["tim.it"]		= {
+	name="tin.lua",
+	args={folder="INBOX"}
+}
 
 -- lycos
 freepops.MODULES_MAP["lycos.co.uk"]	= {name="davmail.lua"}
@@ -57,10 +64,16 @@ freepops.MODULES_MAP["yahoo.it"]       	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.ca"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.co.in"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.tw"] 	= {name="yahoo.lua"}
-freepops.MODULES_MAP["yahoo.com.uk"] 	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.co.uk"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.cn"] 	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.com.br"] 	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.com.hk"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.es"] 	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.de"]        = {name="yahoo.lua"} 
 freepops.MODULES_MAP["yahoo.dk"]        = {name="yahoo.lua"} 
+freepops.MODULES_MAP["rocketmail.com"]  = {name="yahoo.lua"}
+freepops.MODULES_MAP["talk21.com"]  = {name="yahoo.lua"}
+ 
 
 -- hotmail
 freepops.MODULES_MAP["hotmail.com"]		= {name="hotmail.lua"}
@@ -86,7 +99,7 @@ freepops.MODULES_MAP["aol.de"]		= {name="aol.lua"}
 freepops.MODULES_MAP["aol.com.pr"]	= {name="aol.lua"}
 freepops.MODULES_MAP["aol.com.br"]	= {name="aol.lua"}
 freepops.MODULES_MAP["jp.aol.com"]	= {name="aol.lua"}
-freepops.MODULES_MAP["aol.com.uk"]	= {name="aol.lua"}
+freepops.MODULES_MAP["aol.co.uk"]	= {name="aol.lua"}
 freepops.MODULES_MAP["aol.ca"]		= {name="aol.lua"}
 freepops.MODULES_MAP["aola.com"]	= {name="aol.lua"}
 freepops.MODULES_MAP["aim.com"]		= {name="aol.lua"}
@@ -410,6 +423,9 @@ freepops.MODULES_MAP["verizonmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["lycos.com" ]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["unforgettable.com" ]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["mail.org" ]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["italymail.com" ]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["computer4u.com"]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["mexico.com"]		= {name="mailcom.lua"}
 
 -- mail2world
 freepops.MODULES_MAP["mail2.*%.com" ]		= {name="mail2world.lua", 
@@ -420,6 +436,108 @@ freepops.MODULES_MAP["netzero.net"]	= {name="juno.lua"}
 freepops.MODULES_MAP["netzero.com"]	= {name="juno.lua"}	
 freepops.MODULES_MAP["juno.com"]   	= {name="juno.lua"}     
 
+-- fastmail
+freepops.MODULES_MAP["123mail.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["150mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["150ml.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["16mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["2-mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["4email.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["50mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["airpost.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["allmail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["bestmail.us"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["cluemail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["elitemail.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["emailgroups.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["emailplus.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["emailuser.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["eml.cc"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastem.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fast-email.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastemail.us"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastemailer.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastest.cc"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastimap.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmail.cn"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmail.com.au"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmail.fm"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmail.us"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmail.co.uk"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmail.to"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fmail.co.uk"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fast-mail.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmailbox.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fastmessaging.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fea.st"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["f-m.fm"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["fmailbox.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fmgirl.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["fmguy.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["ftml.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["hailmail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["imap.cc"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["imap-mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["imapmail.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["internet-e-mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["internetemails.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["internet-mail.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["internetmailing.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["jetemail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["justemail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["letterboxes.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailandftp.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailas.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailbolt.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailc.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailcan.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mail-central.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailforce.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailftp.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailhaven.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailingaddress.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailite.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailmight.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailnew.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mail-page.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailsent.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailservice.ms"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailup.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mailworks.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["ml1.net"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["mm.st"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["myfastmail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["mymacmail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["nospammail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["ownmail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["petml.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["postinbox.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["postpro.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["proinbox.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["promessage.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["realemail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["reallyfast.biz"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["reallyfast.info"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["rushpost.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["sent.as"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["sent.at"]		= {name="fastmail.lua"}
+freepops.MODULES_MAP["sent.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["speedpost.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["speedymail.org"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["ssl-mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["swift-mail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["the-fastest.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["theinternetemail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["the-quickest.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["veryfast.biz"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["veryspeedy.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["warpmail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["xsmail.com"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["yepmail.net"]	= {name="fastmail.lua"}
+freepops.MODULES_MAP["your-mail.com"]	= {name="fastmail.lua"}
+
+-- criticalpath
+freepops.MODULES_MAP["canada.com"] = {name="criticalpath.lua"}
 
 -- popforward plugin
 
@@ -470,12 +588,12 @@ freepops.MODULES_MAP["aggregator"] 		= {
 -- rss binded domains
 freepops.MODULES_MAP["freepops.rss.en"] 	= {
 	name="aggregator.lua",
-	args={host="http://www.freepops.org/en/misc/backend.rss"}
+	args={host="http://www.freepops.org/en/rss.php"}
 }
 
 freepops.MODULES_MAP["freepops.rss.it"] 	= {
 	name="aggregator.lua",
-	args={host="http://www.freepops.org/it/misc/backend.rss"}
+	args={host="http://www.freepops.org/it/rss.php"}
 }
 
 freepops.MODULES_MAP["flatnuke.sf.net"] 	= {
@@ -550,7 +668,18 @@ freepops.MODULES_MAP["linuxgazette.net"] 	= {
 -- created will be "^(" .. your expression here .. ")$". nil capture means not
 -- matched.
 --
-
+-- remember that multiple rules are supported, but must be comma-separated. 
+-- for example
+--  { ".*@foo.xx" , ".*@example.org", "root@here.xx" }
+-- is a valid LUA syntax, while
+--  { ".*@foo.xx" ".*@example.org" "root@here.xx" }
+-- or 
+--  {
+--    ".*@foo.xx" 
+--    ".*@example.org" 
+--    "root@here.xx"
+--  }
+-- are wrong.
 
 freepops.ACCEPTED_ADDRESSES = {
 	-- empty table means that there is no address that is accepted
