@@ -88,8 +88,8 @@ set_default
 OS=Darwin-static
 CFLAGS="$CFLAGS -I/sw/include -DMACOSX -DOSXSTC"
 HCFLAGS="$HCFLAGS -I/sw/include -DMACOSX -DOSXSTC"
-LDFLAGS="$LDFLAGS -bind_at_load -framework Carbon"
-HLDFLAGS="$HLDFLAGS -bind_at_load"
+LDFLAGS="$LDFLAGS -L/sw/lib -bind_at_load -noprebind -framework Carbon"
+HLDFLAGS="$HLDFLAGS -L/sw/lib -bind_at_load -noprebind"
 }
 
 set_solaris() {
