@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: base64.h,v 1.2 2004/06/12 16:14:08 gareuselesinge Exp $
+ * $Id: base64.h,v 1.3 2005/09/26 22:22:44 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -20,5 +20,8 @@
 char *base64enc_raw(const char *input,size_t len);
 //! base64 encoding
 char *base64enc(const char *input);
+//! base64 decoding
+char *base64dec(const char *input, size_t len);
+
 
 #endif
