@@ -12,6 +12,10 @@
 -- returns only the header, not the the body. If fallback is true then
 -- a GET with range: bytes 0 is tryed<BR/>
 -- <BR/>
+-- <B>get_head_and_body(uri,exhed,fallback)</B> : returns string,string,err and
+-- takes the same arguments of get_uri, but returns as the first value the
+-- header
+-- <BR/>
 -- <B>pipe_uri(uri,callback,exhed)</B> : 
 -- Gets the uri and uses callback on the data
 -- received,exhed  are extra header lines you want to add. <BR> 
@@ -55,7 +59,8 @@
 -- <B>ssl_init_stuff()</B> : some stuff for SSL<BR/>
 --<BR/>
 
-dofile("cookie.lua")
+require("curl")
+local cookie = require("browser.cookie")
 
 -- the methods of a browser objects
 local Private = {}
@@ -145,6 +150,12 @@ function Hidden.build_header(self,url,exhed)
 		table.insert(head,"Cookie: "..cook)
 	end
 	if u.host ~= nil then
+		-- This is a terrible hack.  I had to put it so that hotmail would work.  The
+		-- grammar that hotmail uses differs from the one described in cookie.lua.
+		--
+		if (string.find(u.host, "hotmail") ~= nil) then
+			u.host = string.gsub(u.host, "%?.*$", "")
+		end
 		table.insert(head,"Host: "..u.host)
 	end
 	self.curl:setopt(curl.OPT_HTTPHEADER,head)
@@ -269,6 +280,14 @@ function Hidden.errorcode(ret)
 	return nil,(ret .. ": " .. (Hidden.errors[ret] or "unknown error"))
 end
 
+-- HTTP CONNECT Proxy 2xx
+function Hidden.is_https_proxy_tunnel(b, url, ret)
+	return (b.proxy ~= nil) and 
+		(string.sub(url, 1, 5) == "https") and 
+		(ret == "200")
+end
+	
+
 -- reads the HTTP return code and returns
 -- nil,error if an error
 -- DONE,nil if ok
@@ -283,22 +302,8 @@ function Hidden.parse_header(self,gl_h,url)
 		table.foreach(gl_h,print)
 		return Hidden.error("malformed HTTP header line: "..gl_h[1])
 	end
-	
-	-- HTTP 1xx
-	if string.byte(ret,1) == string.byte("1",1) then
-		local gl_h1 = {} -- to not lose the real header
-		local end_of_1xx = false
-		for i=1,table.getn(gl_h) do
-			if end_of_1xx then
-				table.insert(gl_h1,gl_h[i])
-			end
-			if gl_h[i] == "\r\n" then
-				end_of_1xx = true
-			end
-		end
-		return Hidden.parse_header(self,gl_h1,url)
 	-- HTTP 2xx
-	elseif string.byte(ret,1) == string.byte("2",1) then
+	if string.byte(ret,1) == string.byte("2",1) then
 		if self.followRefreshHeader == true then
 			local l = Hidden.get_refresh_location(gl_h)
 			if l ~= nil then
@@ -325,6 +330,24 @@ function Hidden.parse_header(self,gl_h,url)
 	-- HTTP 5xx
 	elseif string.byte(ret,1) == string.byte("5",1) then
 		return Hidden.errorcode(ret)
+	-- HTTP 1xx or HTTPS proxy tunnel
+	elseif string.byte(ret,1) == string.byte("1",1) or 
+	   Hidden.is_https_proxy_tunnel(self, url, ret) then
+		local gl_h1 = {} -- to not lose the real header
+		local end_of_1xx = false
+		for i=1,table.getn(gl_h) do
+			if end_of_1xx then
+				table.insert(gl_h1,gl_h[i])
+			end
+			if gl_h[i] == "\r\n" then
+				end_of_1xx = true
+			end
+		end
+		if gl_h1[1] ~= nil then
+			return Hidden.parse_header(self,gl_h1,url)
+		else
+			return Hidden.error("Malformed HTTP/1.x 1xx header")
+		end
 	else
 		return Hidden.error("Unsupported HTTP "..ret.." code")
 	end
@@ -369,10 +392,31 @@ function Hidden.perform(self,url,gl_h,gl_b)
 
 end
 
+-- return true if the table contains strings (checks only the first argument)
+function Hidden.is_a_string_table(t)
+	if type(t[1]) == "string" then
+		return true
+	else
+		return false
+	end
+end
+
 -- to not do by hand the call if we get a 3xx code
 function Hidden.continue_or_return(rc,err,t,f,...)
 	if rc == Hidden.DONE then
-		return table.concat(t),nil
+		if type(t) == "table" then
+			if Hidden.is_a_string_table(t) then
+				return table.concat(t),nil
+			else
+				-- we are in the case of the get_head_and_body
+				return 
+					table.concat(t[1] or {}),
+					table.concat(t[2] or {}),nil
+			end
+		else
+			error("Hidden.continue_or_return(_,_,t,...): "..
+				"t of invalit type")
+		end
 	elseif rc == Hidden.REDO then
 		return f(unpack(arg))
 	elseif rc == nil then
@@ -424,6 +468,20 @@ function Private.get_uri(self,url,exhed)
 		Private.get_uri,self,Hidden.mangle_location(self,err),exhed)
 end
 
+function Private.get_head_and_body(self,url,exhed)
+	local gl_b,gl_h = {},{}
+	
+	self.curl:setopt(curl.OPT_HTTPGET,1)
+	self.curl:setopt(curl.OPT_CUSTOMREQUEST,"GET")
+	
+	Hidden.build_header(self,url,exhed)
+	
+	local rc,err = Hidden.perform(self,url,gl_h,gl_b)
+
+	return Hidden.continue_or_return(rc,err,{gl_h,gl_b},
+		Private.get_uri,self,Hidden.mangle_location(self,err),exhed)
+end
+
 function Private.custom_get_uri(self,url,custom,exhed)
 	local gl_b,gl_h = {},{}
 	
@@ -538,15 +596,15 @@ function Private.pipe_uri_with_header(self,url,cb_h,cb_b,exhed)
 end
 
 function Private.show(self)
-	print("browser:\n\tcookies:")
+	log.dbg("browser:\n\tcookies:")
 	table.foreach(self.cookies,function(_,c)
-		table.foreach(c,function(a,b) print("\t\t"..a.."="..b) end)
-		print("\n")
+		table.foreach(c,function(a,b) log.dbg("\t\t"..a.."="..b) end)
+		log.dbg("\n")
 	end)
-	print("\treferrer:\n\t\t" .. (self.referrer or ""))
-	print("\tproxy:\n\t\t" .. (self.proxy or ""))
-	print("\tproxyauth:\n\t\t" .. (self.proxyauth or ""))
-	print("\tuseragent:\n\t\t" .. (self.useragent or ""))
+	log.dbg("\treferrer:\n\t\t" .. (self.referrer or ""))
+	log.dbg("\tproxy:\n\t\t" .. (self.proxy or ""))
+	log.dbg("\tproxyauth:\n\t\t" .. (self.proxyauth or ""))
+	log.dbg("\tuseragent:\n\t\t" .. (self.useragent or ""))
 end
 
 function Private.init_curl(self)
@@ -648,14 +706,15 @@ function Private.verbose_mode(self)
 	self.curl:setopt(curl.OPT_VERBOSE,1)
 end
 
-browser = {}
 
 --<==========================================================================>--
 
+module("browser")
+
 ---
 -- Creates a new object.
 -- @return object.
-function browser.new(override_useragent)
+function new(override_useragent)
 	local b = {
 		cookies = {},
 		referrer = false, --nil will break the metatable check
@@ -687,9 +746,9 @@ end
 ---
 -- Returns true if the browser is SSL enabled.
 -- @return boolean.
-function browser.ssl_enabled()
+function ssl_enabled()
 	local s = curl.version()
-	local _,_,x = string.find(s,"([Ss][Ss][Ll])")
+	local _,_,x = string.find(s,"([SsTt][SsLl][LlSs])")
 	return x ~= nil
 end
 
