@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mlex.c,v 1.4 2004/06/10 12:06:12 gareuselesinge Exp $
+ * $Id: mlex.c,v 1.7 2005/10/24 22:43:58 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -371,10 +371,13 @@ else if( str[t->start] == 'O')
 	return 0;
 else if(str[t->start] == '\0')
 	return 0;
-else
+else 
+	{
 	DBG("we got a '%c'\n",str[t->start]);
 	DBG("string was '%s'\n",&str[t->start]);
-	ERROR_ABORT("Internal error : not X nor O");
+	ERROR_PRINT("Internal error : not X nor O (O of Ohio, not 0 of zero)");
+	return 0;
+	}
 }
 
 /***  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  *  **
@@ -630,8 +633,8 @@ if(l != NULL)
 	}
 else
 	{
-	DBG("you are asking for %d\n",pos);
-	ERROR_PRINT("Internal: wrong position\n");
+	//DBG("you are asking for %d\n",pos);
+	//ERROR_PRINT("Internal: wrong position\n");
 	return NULL;
 	}
 
@@ -653,8 +656,8 @@ if(l != NULL)
 	}
 else
 	{
-	DBG("you are asking for %d\n",pos);
-	ERROR_PRINT("Internal: wrong position\n");
+	//DBG("you are asking for %d\n",pos);
+	//ERROR_PRINT("Internal: wrong position\n");
 	return NULL;
 	}
 }
@@ -1070,9 +1073,9 @@ struct chunk_t* tmp = mlmatch_get_x(mlmatch_get_y(res,y),x);
 
 if(tmp == NULL)
 	{
-	DBG("you are asking for %d %d here :\n",x,y);
-	mlmatch_print_results(res,s);
-	ERROR_ABORT("FIX ME");
+	//DBG("you are asking for %d %d here :\n",x,y);
+	//mlmatch_print_results(res,s);
+	return NULL;
 	}
 	
 return mlmatch_get(tmp,s);
@@ -1117,13 +1120,15 @@ if(len_g != len_r)
 	{
 	DBG("Internal: len(exp)=%d != len(get)=%d",
 		len_r,len_g);
-	ERROR_ABORT("list_len(g) != list_len(r)\n");
+	ERROR_PRINT("list_len(g) != list_len(r)\n");
+	goto abort;
 	}
 if(min_len_g != min_len_r)
 	{
 	DBG("Internal: min_len(exp)=%d != min_len(get)=%d",
 		min_len_r,min_len_g);
-	ERROR_ABORT("exp_min_len(g) != exp_min_len(r)\n");
+	ERROR_PRINT("exp_min_len(g) != exp_min_len(r)\n");
+	goto abort;
 	}
 
 //check for ambiguous matches
@@ -1144,10 +1149,11 @@ printf("\n");
 
 x = mlmatch_epurate(a,str,g,get);
 
+list_free(a,free_answer);
+abort:
 list_free(l,free);
 list_free(r,free);
 list_free(g,free);
-list_free(a,free_answer);
 
 return x;
 }
