@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: popserver.c,v 1.14 2005/11/16 21:25:31 gareuselesinge Exp $
+ * $Id: popserver.c,v 1.15 2006/01/15 19:43:13 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -176,10 +176,10 @@ else	{
 		SAY(fmt,pid,c);
 	if (matches(SOCK_ERROR "Error calling \"recvstring_with_timeout",c))
 		{
-		ERROR_SAY(fmt,pid,"Probably the client disconnected.");
-		ERROR_SAY(fmt,pid,"Try increasing the client timeout.\n");
+		ERROR_PRINT(fmt,pid,"Probably the client disconnected.");
+		ERROR_PRINT(fmt,pid,"Try increasing the client timeout.\n");
 		}
-	DBG("[%d] %s\n",pid,c);	
+	DBG("[%d] %s",pid,c);	
 	}
 }
 
