@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: socketcommon.c,v 1.5 2005/09/25 11:55:53 gareuselesinge Exp $
+ * $Id: socketcommon.c,v 1.6 2006/01/13 23:01:49 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -280,7 +280,7 @@ return (tmp);
 struct sock_state_t * sock_listen(struct sock_state_t * s)
 {
 struct sockaddr sockaddr;
-int addrlen = sizeof(sockaddr);
+unsigned int addrlen = sizeof(sockaddr);
 int newsock;
 
 memset(&sockaddr, 0, sizeof(sockaddr));
