@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: win32_resources.h,v 1.3 2004/10/30 12:36:18 gareuselesinge Exp $
+ * $Id: win32_resources.h,v 1.4 2005/06/30 17:05:23 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -37,9 +37,11 @@ Really important contributions like code, plugins, translations from:\n\
 	Pegasus\n\
 	Eddi De Pieri\n\
 	Lisardo Bello\n\
+	fvancaen\n\
+	...and many more...\n\
 \n\
 For more infos look at the web site:\n\
-	http://freepops.org"
+	http://www.freepops.org"
 
 #define DOWNLOAD_STRING "\
 Autoupdate completed."
