@@ -7,12 +7,12 @@
 -- XML is a pretty flexible language, good for doing nothig, bad for doing all.
 -- Since it is really generic it may allow the reuse of of some tools... 
 -- But what do you think?! Isn't grep a reused peace of code?
--- Anyway it seem that doing XML stuff is for real men.
+-- Anyway it seems that doing XML stuff is for real men.
 -- So everithing is done in XML nowadays.<br/>
 -- Why I don't like it much? Simple, there is no way to access it 
 -- with the language. You have to parse it and transform it in a 
 -- more handy format for your internal purpose, elaborate it and 
--- then retranform you data structure in XML.<br/>
+-- then retransform you data structure in XML.<br/>
 -- So this module is
 -- for the step of internalizing an XML tree into a LUA table. 
 -- This means that you will be able to travferse the tree in the
@@ -230,7 +230,7 @@ end
 -- extern function
 --==========================================================================--
 
-xml2table = {}
+module("xml2table")
 
 ---
 -- Converts XML data in a table.
@@ -244,7 +244,7 @@ xml2table = {}
 -- @param force_encoding string To force the encoding of the XML,
 --  putting "UTF-8" solves some problems with strange encodings.
 -- @return table the resulting table or nil follwed by msg,line,col.
-function xml2table.xml2table(s,m,force_encoding)
+function xml2table(s,m,force_encoding)
 	local tab = {s=Private.stack.new()}
 	local handle_namespaces = nil
 	if m == nil then
@@ -276,7 +276,7 @@ end
 ---
 -- This is a selective table-foreach.
 -- A correct usage is forach_son(t,"D__resposnse",f).
-function xml2table.forach_son(t,sonname,f)
+function forach_son(t,sonname,f)
 	table.foreachi(t,function(_,v)
 		if v.tag_name == sonname then
 			f(v)
