@@ -16,19 +16,19 @@
 -- ************************************************************************** --
 --  FreePOPs RSS/RDF aggregator xml news interface
 --  
---  $Id: aggregator.lua,v 1.37 2005/04/06 20:09:08 alessiofender Exp $
+--  $Id: aggregator.lua,v 1.41 2006/01/26 01:39:18 russell822 Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Simone Vellei <simone_vellei@users.sourceforge.net>
 -- ************************************************************************** --
 
 -- these are used in the init function
-PLUGIN_VERSION = "0.0.5"
+PLUGIN_VERSION = "0.0.7"
 PLUGIN_NAME = "RSS/RDF aggregator"
-PLUGIN_REQUIRE_VERSION = "0.0.14"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=aggregator.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=aggregator.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Simone Vellei"}
 PLUGIN_AUTHORS_CONTACTS = {"simone_vellei (at) users (.) sourceforge (.) net"}
 PLUGIN_DOMAINS = {"@aggregator","@..."}
@@ -184,13 +184,20 @@ end
 --------------------------------------------------------------------------------
 -- Build a mail header
 --
+function make_valid_domain(s)
+	s = string.gsub(s,"[^%a%d-_]",".")
+	s = string.gsub(s,"%.+",".")
+	return s
+end
+
 function build_mail_header(title,uidl,mydate)
 	return 
 	"Message-Id: <"..uidl..">\r\n"..
-	"To: "..internal_state.name.."@"..internal_state.password.."\r\n"..
+	"To: "..internal_state.name.."@"..
+		make_valid_domain(internal_state.password).."\r\n"..
 	"Date: "..build_date(mydate).."\r\n"..
 	"Subject: "..title.."\r\n"..
-	"From: freepops@"..internal_state.password.."\r\n"..
+	"From: freepops@"..make_valid_domain(internal_state.password).."\r\n"..
 	"User-Agent: freepops "..PLUGIN_NAME..
 		" plugin "..PLUGIN_VERSION.."\r\n"..
 	"MIME-Version: 1.0\r\n"..
@@ -289,7 +296,7 @@ function retr_or_top(pstate,msg,data,lines)
 	end
 
 	--clean it
-	header=string.gsub(header,"&amp;","&");
+	header=html2txt(header)
 	title=html2txt(title)
 	body=html2txt(body)
 
@@ -539,14 +546,10 @@ function init(pstate)
 		PLUGIN_NAME.."' version '"..PLUGIN_VERSION.."' started!\n")
 
 	-- the browser module
-	if freepops.dofile("browser.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("browser")
 	
 	-- the common implementation module
-	if freepops.dofile("common.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("common")
 	
 	-- checks on globals
 	freepops.set_sanity_checks()
