@@ -7,18 +7,18 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.8c"
+PLUGIN_VERSION = "0.0.9c"
 PLUGIN_NAME = "aol.com"
-PLUGIN_REQUIRE_VERSION = "0.0.21"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?file=aol.lua"
-PLUGIN_HOMEPAGE = "http://www.freepops.org/"
+PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=aol.lua"
+PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
 PLUGIN_AUTHORS_NAMES = {"Russell Schwager"}
 PLUGIN_AUTHORS_CONTACTS = {"russells (at) despammed (.) com"}
 PLUGIN_DOMAINS = {
 "@aol.com","@aol.com.ar","@aol.fr","@aol.com.mx","@aol.com.au","@aol.de",
 "@aol.com.pr","@aol.com.br","@jp.aol.com","@aol.com.uk","@aol.ca","@aola.com", 
-"@netscape.net", "@aim.com"} 
+"@aim.com"} 
 PLUGIN_PARAMETERS = 
 	{name="folder", description={
 		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox. Gli altri valori possibili sono: Junk, Trash, Draft, Sent.]],
@@ -50,12 +50,12 @@ and your real password as the password.]]
 local globals = {
   -- Server URL
   -- 
-  strLoginUrl = "http://my.screenname.aol.com/_cqr/login/login.psp?seamless=novl&sitedomain=beta.webmail.aol.com&lang=en&locale=us&authLev=2&siteState=",
-  strLoginAIMUrl = "http://my.screenname.aol.com/_cqr/login/login.psp?mcState=initialized&seamless=novl&sitedomain=mail.aol.com&lang=en&locale=us&authLev=2&siteState=", --ver%3a1%252c0%26ld%3amail.aol.com",
+  strLoginUrlAOL = "http://my.screenname.aol.com/_cqr/login/login.psp?sitedomain=registration.aol.com&authLev=1&siteState=OrigUrl%3Dhttp%253a%252f%252fregistration%252eaol%252ecom%252fmail%253fs%255furl%253dhttp%25253a%25252f%25252fwebmail%25252eaol%25252ecom%25252f%25255fcqr%25252fLoginSuccess%25252easpx%25253fsitedomain%25253dsns%25252ewebmail%25252eaol%25252ecom%252526siteState%25253dver%2525253a1%252525252c0%25252526ld%2525253awebmail%25252eaol%25252ecom%25252526pv%2525253aAOL%25252526lc%2525253aen%25252dus%25252526ud%2525253aaol%25252ec",
+  strLoginUrlNetscape = "http://mail.netscape.com",
 
   -- Login strings
   --
-  strLoginPostData = "screenname=%s&password=%s",
+  strLoginPostData = "loginId=%s&password=%s",
   strLoginFailed = "Login Failed - Invalid User name and/or password",
 
   -- Logout
@@ -73,8 +73,8 @@ local globals = {
   
   -- Pattern to extract the URL to go to get the login form
   --
-  strLoginPageParamsPattern='goToLoginUrl.-Redir."([^"]+)"',
-  strLoginPageParamsPatternAim = 'snsInFrameRedir."([^"]+)".;',
+  strLoginWebmailRedirect = 'replace."([^"]+)"',
+  strLoginPageParamsPattern = 'goToLoginUrl.-Redir."([^"]+)"',
 
   -- Pattern to pull out the url's we need to go to set some cookies.
   --
@@ -100,11 +100,11 @@ local globals = {
 
   -- Used by Stat to pull out the message ID and the size
   --
-  strMsgLinePattern = 'new parent%.MessageInfo%("([^"]+)",[^,]+,"[^"]+",[^,]+,([^,]+),',
+  strMsgLinePattern = 'new MI%("([^"]+)",[^,]+,"[^"]+",[^,]+,([^,]+),',
 
   -- Defined Mailbox names - These define the names to use in the URL for the mailboxes
   --
-  strInbox = "New%20Mail", 
+  strInboxAOL = "New%20Mail", 
   strSpamAOL = "Spam",
   strOldboxAOL = "Old%20Mail",
   strTrashAOL = "Recently%20Deleted",
@@ -112,14 +112,7 @@ local globals = {
   StrSavedAOL = "Saved%20Mail",
 
   strInboxAim = "Inbox",
-  strTrashAim = "Trash",
-  strSentAim = "Sent",
-  strDraftsAim = "Drafts",
   
-  strTrashNetscape = "VHJhc2g=",
-  strSentNetscape = "U2VudA==",
-  strDraftNetscape = "RHJhZnQ=",
-
   strInboxPat = "([Nn]ew)",
   strOldboxPat = "([Oo]ld)",
   strSpamPat = "([Ss]pam)",
@@ -136,8 +129,8 @@ local globals = {
   -- Command URLS
   --
   strCmdMsgList = "http://%s/GetMessageList.aspx?user=%s&page=%d&folder=%s&previousFolder=&stateToken=&newMailToken=&version=%s",
-  strCmdDelete = "http://%s/rpc_messages.aspx?folder=%s&action=delete&user=%s&version=%s", --&uid=X",
-  strCmdMsgView = "http://%s/rfc822.aspx?user=%s&folder=%s&uid=%s",
+  strCmdDelete = "http://%s/%s/%s/en-us/RPC/messageAction.aspx?folder=%s&action=delete&user=%s&version=%s", --&uid=X",
+  strCmdMsgView = "http://%s/%s/%s/en-us/Mail/rfc822.aspx?user=%s&folder=%s&uid=%s",
   strCmdWelcome = "http://%s/MessageList.aspx",
 
   -- Site IDs
@@ -162,8 +155,40 @@ internalState = {
   strSiteId = "",
   strUserId = nil,
   strVersion = "",
+  strBrand = "",
 }
 
+-- ************************************************************************** --
+--  Logging functions
+-- ************************************************************************** --
+
+-- Set to true to enable Raw Logging
+--
+local ENABLE_LOGRAW = false
+
+-- The platform dependent End Of Line string
+-- e.g. this should be changed to "\n" under UNIX, etc.
+local EOL = "\r\n"
+
+-- The raw logging function
+--
+log = log or {} -- fast hack to make the xml generator happy
+log.raw = function ( line, data )
+  if not ENABLE_LOGRAW then
+    return
+  end
+
+  local out = assert(io.open("log_raw.txt", "ab"))
+  out:write( EOL .. os.date("%c") .. " : " )
+  out:write( line )
+  if data ~= nil then
+    out:write( EOL .. "--------------------------------------------------" .. EOL )
+    out:write( data )
+    out:write( EOL .. "--------------------------------------------------" )
+  end
+  assert(out:close())
+end
+
 -- ************************************************************************** --
 --  Helper functions
 -- ************************************************************************** --
@@ -184,12 +209,13 @@ function serialize_state()
 		internalState.browser:serialize("internalState.browser")
 end
 
--- Computes the hash of our state.  Concate the user, domain and mailbox.
+-- Computes the hash of our state.  Concate the user, domain, mailbox and password
 --
 function hash()
   return (internalState.strUser or "") .. "~" ..
          (internalState.strDomain or "") .. "~"  ..
-         (internalState.strMBox or "")
+         (internalState.strMBox or "") .. "~" ..
+	 internalState.strPassword -- this asserts strPassword ~= nil
 end
 
 -- Issue the command to login to AOL
@@ -210,9 +236,9 @@ function loginAOL()
   local username = internalState.strUser
   local password = curl.escape(internalState.strPassword)
   local domain = internalState.strDomain
-  local url = globals.strLoginUrl  --string.format(globals.strLoginUrl, internalState.strSiteId)
-  if (domain == "aim.com") then
-    url = globals.strLoginAIMUrl
+  local url = globals.strLoginUrlAOL  
+  if (domain == "netscape.net") then
+    url = globals.strLoginUrlNetscape
   end
   local xml = globals.strFolderQry
   local browser = internalState.browser
@@ -233,11 +259,6 @@ function loginAOL()
   --
   local body, err = browser:get_uri(url)
 
-  -- We need to add a cookie.
-  --
-  --local c = cookie.parse_cookies("MC_COOKIETEST=YES; path=/", browser:wherearewe())
-  browser:add_cookie(url, "MC_COOKIETEST=YES; path=/")
-
   -- No connection
   --
   if body == nil then
@@ -248,11 +269,7 @@ function loginAOL()
   -- The login page sends us to a page that tests cookies and javascript.  We
   -- don't run javascript and thus must do the work here of pulling out the URL that
   -- the javascript would redirect too.
-  if domain == "aim.com" then
-    _, _, url = string.find(body, globals.strLoginPageParamsPatternAim)
-  else
-    _, _, url = string.find(body, globals.strLoginPageParamsPattern)
-  end
+  _, _, url = string.find(body, globals.strLoginPageParamsPattern)
   if (url == nil) then
     log.error_print("Unable to figure out the redirect on the login page.")
     return POPSERVER_ERR_UNKNOWN
@@ -281,7 +298,8 @@ function loginAOL()
   end
   postdata = postdata .. "&" .. 
     string.format(globals.strLoginPostData, username, password)
-  url = "http://" .. browser:wherearewe() .. url
+  url = "https://" .. browser:wherearewe() .. url
+
   body, err = browser:post_uri(url, postdata)
 
   -- This is where things get a little hokey.  AOL returns a page with three javascript
@@ -303,6 +321,7 @@ function loginAOL()
   --
   _, _, url = string.find(body, "checkErrorAndSubmitForm%([^,]+, [^,]+, '([^']+)'")
   if url == nil then
+    log.raw(body)
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_AUTH  
   end
@@ -311,9 +330,11 @@ function loginAOL()
   -- We should be logged in now! Let's check and make sure.
   --
   local str = nil
-  _, _, str = string.find(body, globals.strRetLoginGoodLoginAim)
-  if str == nil then
-    _, _, str = string.find(body, globals.strRetLoginGoodLogin)
+  if (body ~= nil) then
+    _, _, str = string.find(body, globals.strRetLoginGoodLoginAim)
+    if str == nil then
+      _, _, str = string.find(body, globals.strRetLoginGoodLogin)
+    end
   end
   if str == nil then
     log.error_print(globals.strLoginFailed)
@@ -358,8 +379,8 @@ function loginAOL()
 	
   -- Debug info
   --
-  log.dbg("Created session (ID: " .. hash() .. ", User: " .. 
-    internalState.strUser .. "@" .. internalState.strDomain .. ")\n")
+  log.dbg("Created session for " .. 
+    internalState.strUser .. "@" .. internalState.strDomain .. "\n")
 
   -- Return Success
   --
@@ -380,7 +401,8 @@ function downloadMsg(pstate, msg, nLines, data)
   --
   local browser = internalState.browser
   local uidl = get_mailmessage_uidl(pstate, msg)
-  local url = string.format(globals.strCmdMsgView, internalState.strMailServer, internalState.strUserId,
+  local url = string.format(globals.strCmdMsgView, internalState.strMailServer, 
+    internalState.strVersion, internalState.strBrand, internalState.strUserId,
     internalState.strMBox, uidl);
 
   -- Debug Message
@@ -482,20 +504,22 @@ function user(pstate, username)
 
   -- Set the site id
   -- 
-  if domain == "netscape.net" then
-    internalState.strSiteId = globals.strNetscapeID
+  if domain == "aim.com" then
+    internalState.strBrand = "aim"
+  elseif domain == "netscape.net" then
+    internalState.strBrand = "nc"
   else
-    internalState.strSiteId = globals.strAOLID
+    internalState.strBrand = "aol"
   end
 
   -- Get the folder
   --
   local mbox = (freepops.MODULE_ARGS or {}).folder
   if mbox == nil then
-    if domain == "aim.com" then
+    if domain == "aim.com" or domain == "netscape.net" then
       internalState.strMBox = globals.strInboxAim
     else
-      internalState.strMBox = globals.strInbox
+      internalState.strMBox = globals.strInboxAOL
     end
     return POPSERVER_ERR_OK
   end
@@ -508,9 +532,7 @@ function user(pstate, username)
 
   _, _, start = string.find(mbox, globals.strSentPat)
   if start ~= nil then
-    if domain == "aim.com" then
-      internalState.strMBox = globals.strSentAim
-    else
+    if domain ~= "aim.com" and domain ~= "netscape.net" then
       internalState.strMBox = globals.strSentAOL
     end
     return POPSERVER_ERR_OK
@@ -518,25 +540,12 @@ function user(pstate, username)
 
   _, _, start = string.find(mbox, globals.strDeletedPat)
   if start ~= nil then
-    if domain == "aim.com" then
-      internalState.strMBox = globals.strTrashAim
-    else
+    if domain ~= "aim.com" and domain ~= "netscape.net" then
       internalState.strMBox = globals.strTrashAOL
     end
     return POPSERVER_ERR_OK
   end
 
-  _, _, start = string.find(mbox, globals.strTrashPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strTrashNetscape
-    return POPSERVER_ERR_OK
-  end
-
-  _, _, start = string.find(mbox, globals.strDraftPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strDraftAim
-    return POPSERVER_ERR_OK
-  end
 
   _, _, start = string.find(mbox, globals.strOldboxPat)
   if start ~= nil then
@@ -632,7 +641,8 @@ function quit_update(pstate)
   local cnt = get_popstate_nummesg(pstate)
   local dcnt = 0
 
-  local cmdUrl = string.format(globals.strCmdDelete, internalState.strMailServer, 
+  local cmdUrl = string.format(globals.strCmdDelete, internalState.strMailServer,
+    internalState.strVersion, internalState.strBrand, 
     internalState.strMBox, internalState.strUserId, internalState.strVersion)
   local baseUrl = cmdUrl
 
@@ -886,27 +896,19 @@ function init(pstate)
 
   -- Serialization
   --
-  if freepops.dofile("serialize.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end 
+  require("serial")
 
   -- Browser
   --
-  if freepops.dofile("browser.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("browser")
 	
   -- MIME Parser/Generator
   --
-  if freepops.dofile("mimer.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end	
+  require("mimer")
 
   -- Common module
   --
-  if freepops.dofile("common.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("common")
 	
   -- Run a sanity check
   --
