@@ -7,9 +7,9 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.1"
+PLUGIN_VERSION = "0.0.2a"
 PLUGIN_NAME = "fastmail.com"
-PLUGIN_REQUIRE_VERSION = "0.0.31"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org/download.php?file=fastmail.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
@@ -200,12 +200,13 @@ function serialize_state()
 		internalState.browser:serialize("internalState.browser")
 end
 
--- Computes the hash of our state.  Concate the user, domain and mailbox.
+-- Computes the hash of our state.  Concate the user, domain, mailbox and password
 --
 function hash()
   return (internalState.strUser or "") .. "~" ..
          (internalState.strDomain or "") .. "~"  ..
-         (internalState.strMBox or "")
+         (internalState.strMBox or "") .. "~"  ..
+	 internalState.strPassword -- this asserts strPassword ~= nil
 end
 
 -- Issue the command to login to fastmail
@@ -339,8 +340,8 @@ function login()
 	
   -- Debug info
   --
-  log.dbg("Created session (ID: " .. hash() .. ", User: " .. 
-    internalState.strUser .. "@" .. internalState.strDomain .. ")\n")
+  log.dbg("Created session for " .. 
+    internalState.strUser .. "@" .. internalState.strDomain .. "\n")
 
   -- Return Success
   --
@@ -915,27 +916,19 @@ function init(pstate)
 
   -- Serialization
   --
-  if freepops.dofile("serialize.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end 
+  require("serial")
 
   -- Browser
   --
-  if freepops.dofile("browser.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("browser")
 	
   -- MIME Parser/Generator
   --
-  if freepops.dofile("mimer.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end	
+  require("mimer")
 
   -- Common module
   --
-  if freepops.dofile("common.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("common")
 	
   -- Run a sanity check
   --
