@@ -12,15 +12,31 @@ freepops = {}
 -- <TT>config(dot)lua</TT> for a bunch of examples.
 freepops.MODULES_MAP = {}
 
----
--- List of loaded so/dll/lua libs.
-freepops.LOADED = {}
-
 ---
 -- This is a global variable that the plugins may read, see the libero plugin
 -- for an example.
 freepops.MODULE_ARGS = nil
 
+---
+-- List of loaded so/dll/lua libs.
+-- XXX DEPRECATED XXX 
+--   we use compat-5.1 'require' system
+--   we temporarily add a metatable to print a warning
+  freepops.LOADED = {}
+  local real_freepops_dot_LOADED = {}
+  setmetatable(freepops.LOADED,{
+  	__index = function(t,k) 
+		log.error_print("method deprecated. please use 'require'"..
+			" to load "..k)
+		return real_freepops_dot_LOADED[k]
+	end,
+  	__newindex = function(t,k,v) 
+		log.error_print("method deprecated. please use 'require'"..
+			" to load "..k)
+		real_freepops_dot_LOADED[k] = v
+	end
+  })
+
 --<==========================================================================>--
 -- This metatable/metamethod avoid accessing wrong fields of the tabe
 fp_m = { 
@@ -69,7 +85,6 @@ local function load_config()
 		error("Unable to load config.lua. Path is "..
 			table.concat(paths,":"))
 	end
-
 end
 
 -- Required methods for a plugin.
@@ -171,7 +186,7 @@ function freepops.safe_extract_domains(f)
 
 	-- the hack
 	setmetatable(env,meta_env)
-	local g, err = loadfile(f)
+	local g, err = __loadfile(f)
 	if g  == nil then
 		log.dbg(err)
 		return nil
@@ -359,7 +374,8 @@ function freepops.find(file)
 			return path..file
 		end
 	end
-	if try(_,"") ~= nil then
+        local foo
+	if try(foo,"") ~= nil then
 		return file
 	end
 	return table.foreach(freepops.MODULES_PREFIX,try)
@@ -425,13 +441,7 @@ end
 
 ---
 -- uses freepops' dofile instead of the standard one.
-dofile = freepops.dofile
----
--- uses freepops' loadlib instead of the standard one.
-loadlib = freepops.loadlib
----
--- uses freepops' loadfile instead of the standard one.
-loadfile = freepops.loadlib
+dofile = function(f) return require(f) or freepops.dofile(f) end
 
 ---
 -- Load needed module for handling domain.
@@ -689,14 +699,24 @@ end
 function freepops.bootstrap()
 	load_config()
 	
+	-- compat-5.1
+	LUA_PATH=""
+	local function path_to_compat51_path(_,path)
+	        LUA_PATH=LUA_PATH .. path .. "?.lua;"
+	        LUA_PATH=LUA_PATH .. path .. "?/?.lua;"
+	end
+	table.foreach(freepops.MODULES_PREFIX,path_to_compat51_path)
+	table.foreach(freepops.MODULES_PREFIX_UNOFFICIAL,path_to_compat51_path)
+	freepops.dofile("compat-5.1.lua")
+	
 	-- standard lua modules that must be loaded
-	if freepops.dofile("support.lua") == nil then return 1 end
+	if require("support") == nil then return 1 end
 
 	return 0 -- OK
 end
 
 -- -------------------------------------------------------------------------- --
---  This is the only (except the latter) function called from the C code. 
+--  This is the only (except the former) function called from the C code. 
 --  This loads the module that handles mailaddress's domain and load standard
 --  LUA modules
 -- -------------------------------------------------------------------------- --
