@@ -7,9 +7,9 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.1.3a"
+PLUGIN_VERSION = "0.1.5h"
 PLUGIN_NAME = "hotmail.com"
-PLUGIN_REQUIRE_VERSION = "0.0.25"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org/download.php?file=hotmail.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
@@ -23,8 +23,14 @@ PLUGIN_DOMAINS = { "@hotmail.com","@msn.com","@webtv.com",
       }
 PLUGIN_PARAMETERS = {
 	{name="folder", description={
-		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox, gli altri valori possibili sono: Junk, Trash, Draft, Sent.]],
-		en=[[The folder you want to interact with. Default is Inbox, other values are: Junk, Trash, Draft, Sent.]]}
+		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox.]],
+		en=[[The folder you want to interact with. Default is Inbox.]]}
+	},
+	{name = "emptyjunk", description = {
+		en = [[
+Parameter is used to force the plugin to empty the junk folder when it is done
+pulling messages.  Set the value to 1.]]
+		}	
 	},
 	{name = "emptytrash", description = {
 		it = [[ Viene usato per forzare il plugin a svuotare il cestino quando ha finito di scaricare i messaggi. Se il valore &egrave; 1 questo comportamento viene attivato.]],
@@ -39,6 +45,11 @@ pulling messages.  Set the value to 1.]]
 pulls as unread.  If the value is 1, the behavior is turned on.]]
 		}
 	},
+	{name = "maxmsgs", description = {
+		en = [[
+Parameter is used to force the plugin to only download a maximum number of messages. ]]
+		}	
+	},
 }
 PLUGIN_DESCRIPTIONS = {
 	it=[[
@@ -55,10 +66,6 @@ the forum instead of emailing the author(s).]]
 -- Domains supported:  hotmail.com, msn.com, webtv.com, charter.com, compaq.net,
 --                     passport.com
 
--- TODO
--- 
--- - Support user defined mailboxes.  For now, we support: Inbox, Junk, Sent, Drafts, Trash
-
 -- ************************************************************************** --
 --  Global Strings
 -- ************************************************************************** --
@@ -66,7 +73,9 @@ the forum instead of emailing the author(s).]]
 local globals = {
   -- Server URL
   --
-  strLoginUrl = "http://www.hotmail.com/",
+  strLoginUrl = "http://mail.live.com/",
+
+  strDefaultLoginPostUrl = "https://login.live.com/ppsecure/post.srf",
 
   -- Login strings
   -- TODO: Define the HTTPS version
@@ -79,6 +88,7 @@ local globals = {
   --
   strRetLoginBadLogin = "(memberservices)",
   strRetLoginSessionExpired = "(Sign in)",
+  strRetLoginSessionExpiredLive = "(new HM%._)",
   strRetStatBusy = "(form name=.hotmail.)",
   
   -- Regular expression to extract the mail server
@@ -92,19 +102,37 @@ local globals = {
   strLoginPostUrlPattern4='var g_QS="([^"]+)";',
   strLoginPostUrlPattern5='name="PPFT" id="[^"]+" value="([^"]+)"',
   strLoginDoneReloadToHMHome1='URL=([^"]+)"',
-  strLoginDoneReloadToHMHome2='top%.location%.replace%("([^"]+)"',
+  strLoginDoneReloadToHMHome2='%.location%.replace%("([^"]+)"',
+
+  -- Pattern to detect if we are using the live version
+  --
+  strLiveCheckPattern = '(function NewMessageGo)',
+  strLiveMainPagePattern = '<frame name="main" src="([^"]+)"',
 
   -- Get the crumb value that is needed for every command
   --
   strRegExpCrumb = '&a=([^"&]*)[&"]',
+  strRegExpCrumbLive = '"sessionidhash" : "([^"]+)"',                    
+
+  -- MSN Inbox Folder Id
+  --
+  strPatMSNInboxId = "HMFO%('(%d+)'%)[^>]+><img src=.http://[^/]+/i.p.folder.inbox.gif",
 
   -- Image server pattern
   --
   strImgServerPattern = 'img src="(http://[^/]*)/spacer.gif"',
+  strImgServerLivePattern = 'img src="(http://[^/]*)/mail/',
+
+  -- Junk and Trash Folder pattern
+  -- 
+  strPatLiveTrashId = 'i_trash%.gif" /></div>[^<]+<div class="[^"]+"><a href="/mail/mail%.aspx%?Control=Inbox&FolderID=([^"]+)">',
+  strPatLiveJunkId = 'i_junkEmail%.gif" /></div>[^<]+<div class="[^"]+"><a href="/mail/mail%.aspx%?Control=Inbox&FolderID=([^"]+)">',
 
   -- Folder id pattern
   --
   strFolderPattern = '<a href="[^"]+curmbox=([^&]+)&[^"]+" >', 
+  strFolderLivePattern = '<a href="/mail/mail.aspx%?Control=Inbox&FolderID=([^"]+)">',
+  strFolderLiveInboxPattern = 'i_inbox%.gif" /></div>[^<]+<div class="[^"]+"><a href="/mail/mail%.aspx%?Control=Inbox&FolderID=([^"]+)">',
 
   -- Pattern to determine if we have no messages
   --
@@ -128,6 +156,10 @@ local globals = {
   --
   strMsgListGoodBody = 'i%.p%.attach%.gif',
 
+  -- Pattern used in the Live interface to get the message info
+  --
+  strMsgLivePattern = 'new HM%.__[21][28]%([^%)]+[%)]+, "([^"]+)", "[^"]+", "[^"]+", [^,]+, [^,]+, [^,]+, [^,]+, "([^"]+)"',
+
   -- The amount of time that the session should time out at.
   -- This is expressed in seconds
   --
@@ -137,30 +169,30 @@ local globals = {
   --
   strNewFolderPattern = "(curmbox=0)",
   strFolderPrefix = "00000000-0000-0000-0000-000",
-
   strInbox = "F000000001",
-  strJunk =  "F000000005",
-  strTrash = "F000000004",
-  strDraft = "F000000003",
-  strSent =  "F000000002",
-
-  strInboxPat = "([iI]nbox)",
-  strJunkPat = "([Jj]unk)",
-  strSentPat = "([Ss]ent)",
-  strDraftPat = "([Dd]rafts)",
-  strTrashPat = "([Tt]rash)",
 
   -- Command URLS
   --
+  strCmdBaseLive = "http://%s/mail/",
+  strCmdBrowserIgnoreLive = "http://%s/mail/mail.aspx?skipbrowsercheck=true",
   strCmdMsgList = "http://%s/cgi-bin/HoTMaiL?a=%s&curmbox=%s",
   strCmdMsgListNextPage = "&page=%d&wo=",
+  strCmdMsgListLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.GetFolderData&ptid=0&a=%s", 
+  strCmdMsgListPostLive = "cn=Microsoft.Msn.Hotmail.MailBox&mn=GetFolderData&d=%s,Date,%s,false,0,%s,0,,&MailToken=",
   strCmdDelete = "http://%s/cgi-bin/HoTMaiL",
   strCmdDeletePost = "curmbox=%s&_HMaction=delete&wo=&SMMF=0", -- &<MSGID>=on
+  strCmdDeleteLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.MoveMessages&ptid=0&a=%s", 
+  strCmdDeletePostLive = "cn=Microsoft.Msn.Hotmail.MailBox&mn=MoveMessages&d=%s,%s,[%s],[{%%5C%%7C%%5C%%7C%%5C%%7C0%%5C%%7C%%5C%%7C%%5C%%7C%%5C%%7C99999999999990000,null}],null,null,1,false,Date",
   strCmdMsgView = "http://%s/cgi-bin/getmsg?msg=%s&imgsafe=y&curmbox=%s&a=%s",
   strCmdMsgViewRaw = "&raw=0",
+  strCmdMsgViewLive = "http://%s/mail/GetMessageSource.aspx?msgid=%s",
   strCmdEmptyTrash = "http://%s/cgi-bin/dofolders?_HMaction=DoEmpty&curmbox=F000000004&a=%s&i=F000000004",
   strCmdLogout = "http://%s/cgi-bin/logout",
   strCmdFolders = "http://%s/cgi-bin/folders?&curmbox=F000000001&a=%s",
+  strCmdMsgUnreadLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.MarkMessages&ptid=0&a=", 
+  strCmdMsgUnreadLivePost = "cn=Microsoft.Msn.Hotmail.MailBox&mn=MarkMessages&d=false,[%s]",
+  strCmdEmptyTrashLive = "http://%s/mail/mail.fpp?cnmn=Microsoft.Msn.Hotmail.MailBox.EmptyFolder&ptid=0&a=", 
+  strCmdEmptyTrashLivePost = "cn=Microsoft.Msn.Hotmail.MailBox&mn=EmptyFolder&d=%s,0",
 }
 
 -- ************************************************************************** --
@@ -180,8 +212,13 @@ internalState = {
   strMBox = nil,
   strMBoxName = nil,
   bEmptyTrash = false,
+  bEmptyJunk = false,
   loginTime = nil,
   bMarkMsgAsUnread = false,
+  bLiveGUI = false,
+  strTrashId = nil,
+  strJunkId = nil,
+  statLimit = nil,
 }
 
 -- ************************************************************************** --
@@ -236,12 +273,13 @@ function serialize_state()
 		internalState.browser:serialize("internalState.browser")
 end
 
--- Computes the hash of our state.  Concate the user, domain and mailbox.
+-- Computes the hash of our state.  Concate the user, domain, mailbox and password
 --
 function hash()
   return (internalState.strUser or "") .. "~" ..
          (internalState.strDomain or "") .. "~"  ..
-         (string.sub(internalState.strMBox, -5) or "")
+         (internalState.strMBoxName or "") .. "~"  ..
+	 internalState.strPassword -- this asserts strPassword ~= nil
 end
 
 function getPage(browser, url)
@@ -309,7 +347,7 @@ function loginHotmail()
     return POPSERVER_ERR_NETWORK
   end
 
-  -- The login page returns a page where a form needs to be asubmitted.  We'll do it
+  -- The login page returns a page where a form needs to be submitted.  We'll do it
   -- manually.  Extract the form elements and post the data
   -- 
   _, _, url = string.find(body, globals.strLoginPostUrlPattern1)
@@ -333,10 +371,13 @@ function loginHotmail()
   _, _, url = string.find(body, pattern)
   local _, _, str = string.find(body, globals.strLoginPostUrlPattern4)
   local _, _, str2 = string.find(body, globals.strLoginPostUrlPattern5)
-  if (url == nil or str == nil or str2 == nil) then
+  if (str == nil or str2 == nil) then
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_NETWORK
   end
+  if (url == nil) then 
+    url = globals.strDefaultLoginPostUrl 
+  end
   url = url .. "?" .. str 
 
   local padding = string.sub(globals.strLoginPaddingFull, 0, 16 - passwordlen)
@@ -379,17 +420,49 @@ function loginHotmail()
     return POPSERVER_ERR_NETWORK
   end
 
-  -- Save the mail server
+  -- Check to see if we are using the new interface and are redirecting.
   --
-  internalState.strMailServer = browser:wherearewe()
+  local _, _, str = string.find(body, globals.strLiveCheckPattern)
+  local folderBody = body
+  if str ~= nil then
+    log.dbg("Hotmail: Detected LIVE version.") 
+    str = string.format(globals.strCmdBrowserIgnoreLive, browser:wherearewe())
+    body, err = browser:get_uri(str)
+    _, _, str = string.find(body, globals.strLiveMainPagePattern)
+    if str ~= nil then
+      str = string.format(globals.strCmdBaseLive, browser:wherearewe()) .. str
+      body, err = browser:get_uri(str)
+    else
+      log.error_print(globals.strLoginFailed)
+      log.raw("Login failed: Trying to get session id and got something we weren't expecting:\n" .. body);
+      return POPSERVER_ERR_NETWORK
+    end
+
+    internalState.bLiveGUI = true
+  else
+    -- One more redirect
+    --  
+    local oldurl = url
+    _, _, url = string.find(body, globals.strLoginDoneReloadToHMHome1)
+    if url == nil then
+      _, _, url = string.find(body, globals.strLoginDoneReloadToHMHome2)
+      if url == nil then
+        log.error_print(globals.strLoginFailed)
+        log.raw("Login failed: Sent login info to: " .. (oldurl or "none") .. " and got something we weren't expecting(3):\n" .. body);
+        return POPSERVER_ERR_NETWORK
+      end
+    end
+    body, err = browser:get_uri(url)
+  end
 
-  -- DEBUG Message
-  --
-  log.dbg("Hotmail Server: " .. internalState.strMailServer .. "\n")
-  
   -- Extract the crumb - This is needed for deletion of items
   --
-  _, _, str = string.find(body, globals.strRegExpCrumb)
+  if (internalState.bLiveGUI == true) then
+    _, _, str = string.find(body, globals.strRegExpCrumbLive)
+  else
+    _, _, str = string.find(body, globals.strRegExpCrumb)
+  end
+
   if str == nil then
     log.error_print("Can't get the 'a' value. This will lead to problems!")
     internalState.strCrumb = ""
@@ -401,9 +474,22 @@ function loginHotmail()
     log.dbg("Hotmail Crumb value: " .. str .. "\n")
   end
 
+  -- Save the mail server
+  --
+  internalState.strMailServer = browser:wherearewe()
+
+  -- DEBUG Message
+  --
+  log.dbg("Hotmail Server: " .. internalState.strMailServer .. "\n")
+
   -- Find the image server
   --
-  _, _, str = string.find(body, globals.strImgServerPattern)
+  if (internalState.bLiveGUI == true) then
+    _, _, str = string.find(body, globals.strImgServerLivePattern)
+  else
+    _, _, str = string.find(body, globals.strImgServerPattern)
+  end
+  
   if str ~= nil then
     internalState.strImgServer = str
     log.dbg("Hotmail image server: " .. str)
@@ -413,32 +499,64 @@ function loginHotmail()
     log.raw("Login failed: Should be logged in right now but am not.  Last page loaded: " .. url .. " with body:\n" .. body);
   end
 
-  -- See if we are using the new folder id's
-  --
-  _, _, str = string.find(body, globals.strNewFolderPattern)
-  if str ~= nil then
-    internalState.strMBox = globals.strFolderPrefix .. 
-      string.sub(internalState.strMBox, 2, -1) 
-    log.dbg("Hotmail - Using new folder names (" .. internalState.strMBox .. ")")
-  end
-
   -- Note the time when we logged in
   --
   internalState.loginTime = os.clock();
 
   -- If we haven't set the folder yet, then it is a custom one and we need to grab it
   --
-  if (internalState.strMBoxName ~= nil) then
+  internalState.strMBoxName = string.gsub(internalState.strMBoxName, '%-', "%%-")
+  if (internalState.strMBox == nil and internalState.bLiveGUI == false) then
     local url = string.format(globals.strCmdFolders, internalState.strMailServer, 
       internalState.strCrumb)
     body, err = browser:get_uri(url)
     _, _, str = string.find(body, globals.strFolderPattern .. internalState.strMBoxName .. "</a>")
+    if (str == nil and domain == "msn.com" and internalState.strMBoxName == "Inbox") then
+      _, _, str = string.find(body, globals.strPatMSNInboxId)
+    end
     if (str == nil) then
-      log.error_print(globals.strLoginFailed)
+      log.error_print("Unable to figure out folder id with name: " .. internalState.strMBoxName)
       return POPSERVER_ERR_NETWORK
     else
       internalState.strMBox = str
-      log.dbg("Hotmail - Using custom folder (" .. internalState.strMBox .. ")")
+      log.dbg("Hotmail - Using folder (" .. internalState.strMBox .. ")")
+    end
+  elseif (internalState.strMBox == nil and internalState.bLiveGUI == true and 
+          internalState.strMBoxName ~= "Junk") then 
+    if (internalState.strMBoxName == "Inbox") then
+      _, _, str = string.find(folderBody, globals.strFolderLiveInboxPattern)
+    else
+      _, _, str = string.find(folderBody, globals.strFolderLivePattern .. internalState.strMBoxName)
+    end
+    if (str == nil) then
+      log.error_print("Unable to figure out folder id with name: " .. internalState.strMBoxName)
+      return POPSERVER_ERR_NETWORK
+    else
+      internalState.strMBox = str
+      log.dbg("Hotmail - Using folder (" .. internalState.strMBox .. ")")
+    end
+  end
+
+  -- Get the ID of the trash folder
+  --
+  if (internalState.bLiveGUI) then
+    _, _, str = string.find(folderBody, globals.strPatLiveTrashId) 
+    if str ~= nil then
+      internalState.strTrashId = str
+      log.dbg("Hotmail - trash folder id: " .. str)
+    else
+      log.error_print("Unable to detect the folder id for the trash folder.  Deletion may fail.")
+    end
+    _, _, str = string.find(folderBody, globals.strPatLiveJunkId) 
+    if str ~= nil then
+      internalState.strJunkId = str
+      log.dbg("Hotmail - junk folder id: " .. str)
+      if (internalState.strMBoxName == "Junk") then
+        internalState.strMBox = str
+        log.dbg("Hotmail - Using folder (" .. internalState.strMBox .. ")")
+     end
+    else
+      log.error_print("Unable to detect the folder id for the junk folder.  Deletion may fail.")
     end
   end
 
@@ -448,8 +566,8 @@ function loginHotmail()
 	
   -- Debug info
   --
-  log.dbg("Created session (ID: " .. hash() .. ", User: " .. 
-    internalState.strUser .. "@" .. internalState.strDomain .. ")\n")
+  log.dbg("Created session for " .. 
+    internalState.strUser .. "@" .. internalState.strDomain .. "\n")
 
   -- Return Success
   --
@@ -476,6 +594,9 @@ function downloadMsg(pstate, msg, nLines, data)
     uidl, internalState.strMBox, internalState.strCrumb);
   local markReadUrl = url
   url = url .. globals.strCmdMsgViewRaw
+  if (internalState.bLiveGUI == true) then
+    url = string.format(globals.strCmdMsgViewLive, internalState.strMailServer, uidl)
+  end
 
   -- Debug Message
   --
@@ -544,9 +665,14 @@ function downloadMsg(pstate, msg, nLines, data)
 
   -- Mark the message as read
   --
-  if internalState.bMarkMsgAsUnread == false then
+  if internalState.bMarkMsgAsUnread == false and internalState.bLiveGUI == false then
     log.raw("Message: " .. cbInfo.cb_uidl .. ", Marking message as being done.")
     browser:get_head(markReadUrl)
+  elseif internalState.bMarkMsgAsUnread == true and internalState.bLiveGUI == true then
+    log.raw("Message: " .. cbInfo.cb_uidl .. ", Marking message as unread.")
+    url = string.format(globals.strCmdMsgUnreadLive, internalState.strMailServer)
+    local post = string.format(globals.strCmdMsgUnreadLivePost, uidl)
+    browser:post_uri(url, post)
   end
 
   log.raw("Message: " .. cbInfo.cb_uidl .. ", Completed!")
@@ -649,6 +775,8 @@ function cleanupHeaders(headers, cbInfo)
   headers = string.gsub(headers, "%s+$", "\n")
   headers = headers .. "\n";
   headers = string.gsub(headers, "\n\n", "\n")
+  headers = string.gsub(headers, "\r\n", "\n")
+  headers = string.gsub(headers, "\n", "\r\n")
 
   --
   -- some checking...
@@ -685,7 +813,6 @@ function cleanupHeaders(headers, cbInfo)
   return headers 
 end
 
-
 function cleanupBody(body, cbInfo)
   -- check to see whether the end of message has already been seen...
   --
@@ -707,6 +834,7 @@ function cleanupBody(body, cbInfo)
 
   -- Clean up the end of line, and replace HTML tags
   --
+  body = string.gsub(body, "\r", "")
   body = string.gsub(body, "\n", "\r\n")
   body = string.gsub(body, "&amp;", "&")
   body = string.gsub(body, "&lt;", "<")
@@ -751,6 +879,15 @@ function user(pstate, username)
     internalState.bEmptyTrash = true
   end
 
+  -- If the flag emptyjunk is set to 1 ,
+  -- the trash will be emptied on 'quit'
+  --
+  local val = (freepops.MODULE_ARGS or {}).emptyjunk or 0
+  if val == "1" then
+    log.dbg("Hotmail: Junk folder will be emptied on exit.")
+    internalState.bEmptyJunk = true
+  end
+
   -- If the flag markunread=1 is set, then we will mark all messages
   -- that we pull as unread when done.
   --
@@ -760,43 +897,27 @@ function user(pstate, username)
     internalState.bMarkMsgAsUnread = true
   end
 
+  -- If the flag maxmsgs is set,
+  -- STAT will limit the number of messages to the flag
+  --
+  val = (freepops.MODULE_ARGS or {}).maxmsgs or 0
+  if tonumber(val) > 0 then
+    log.dbg("Hotmail: A max of " .. val .. " messages will be downloaded.")
+    internalState.statLimit = tonumber(val)
+  end
+
   -- Get the folder
   --
   local mbox = (freepops.MODULE_ARGS or {}).folder
   if mbox == nil then
-    internalState.strMBox = globals.strInbox
+    internalState.strMBoxName = "Inbox"
     return POPSERVER_ERR_OK
+  else
+    mbox = curl.unescape(mbox)
+    internalState.strMBoxName = mbox
+    log.say("Using Custom mailbox set to: " .. internalState.strMBoxName .. ".\n")
   end
 
-  local _, _, start = string.find(mbox, globals.strJunkPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strJunk
-    return POPSERVER_ERR_OK
-  end
-
-  _, _, start = string.find(mbox, globals.strSentPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strSent
-    return POPSERVER_ERR_OK
-  end
-
-  _, _, start = string.find(mbox, globals.strTrashPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strTrash
-    return POPSERVER_ERR_OK
-  end
-
-  _, _, start = string.find(mbox, globals.strDraftPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strDraft
-    return POPSERVER_ERR_OK
-  end
-
-  -- Defaulting to the inbox
-  --
-  log.say("Custom mailbox set to: " .. mbox .. ".\n")
-  internalState.strMBoxName = mbox
-  internalState.strMBox = globals.strInbox
   return POPSERVER_ERR_OK
 end
 
@@ -877,13 +998,14 @@ function quit_update(pstate)
   local dcnt = 0
   local postBase = string.format(globals.strCmdDeletePost, internalState.strMBox)
   local post = postBase
+  local uidls = ""
 
   -- Cycle through the messages and see if we need to delete any of them
   -- 
   for i = 1, cnt do
-    if get_mailmessage_flag(pstate, i, MAILMESSAGE_DELETE) then
-      post = post .. "&" .. get_mailmessage_uidl(pstate, i) .. "=on"
+    if internalState.bLiveGUI == false and get_mailmessage_flag(pstate, i, MAILMESSAGE_DELETE) then
       dcnt = dcnt + 1
+      post = post .. "&" .. get_mailmessage_uidl(pstate, i) .. "=on"
 
       -- Send out in a batch of 5
       --
@@ -899,22 +1021,35 @@ function quit_update(pstate)
         dcnt = 0
         post = postBase
       end
+    elseif internalState.bLiveGUI == true and get_mailmessage_flag(pstate, i, MAILMESSAGE_DELETE) then
+      if i > 1 then
+        uidls = uidls .. "," .. get_mailmessage_uidl(pstate, i)
+      else
+        uidls = get_mailmessage_uidl(pstate, i)
+      end
+      dcnt = dcnt + 1
     end
   end
 
   -- Send whatever is left over
   --
-  if dcnt > 0 and dcnt < 5 then
+  if dcnt > 0 and internalState.bLiveGUI == false then
     log.dbg("Sending Delete URL: " .. cmdUrl .. "Post Data: " .. post .. "\n")
     local body, err = browser:post_uri(cmdUrl, post)
     if not body or err then
       log.error_print("Unable to delete messages.\n")
     end
+  elseif dcnt > 0 and internalState.bLiveGUI then
+    cmdUrl = string.format(globals.strCmdDeleteLive, internalState.strMailServer, internalState.strCrumb)
+    post = string.format(globals.strCmdDeletePostLive, internalState.strMBox, 
+      internalState.strTrashId, uidls)
+    log.dbg("Sending Trash url: " .. cmdUrl .. " - " .. post)
+    browser:post_uri(cmdUrl, post)
   end
 
   -- Empty the trash
   --
-  if internalState.bEmptyTrash then
+  if internalState.bEmptyTrash and internalState.bLiveGUI == false then
     if internalState.strCrumb ~= '' then
       cmdUrl = string.format(globals.strCmdEmptyTrash, internalState.strMailServer,internalState.strCrumb)
       log.dbg("Sending Empty Trash URL: " .. cmdUrl .."\n")
@@ -925,6 +1060,26 @@ function quit_update(pstate)
     else
       log.error_print("Cannot empty trash - crumb not found\n")
     end
+  elseif internalState.bEmptyTrash and internalState.bLiveGUI then
+    cmdUrl = string.format(globals.strCmdEmptyTrashLive, internalState.strMailServer)
+    local post = string.format(globals.strCmdEmptyTrashLivePost, internalState.strTrashId)
+    log.dbg("Sending Empty Trash URL: " .. cmdUrl .."\n")
+    local body, err = browser:post_uri(cmdUrl, post)
+    if not body or err then
+      log.error_print("Error when trying to empty the trash with url: ".. cmdUrl .."\n")
+    end
+  end
+
+  -- Empty the Junk Folder
+  --
+  if internalState.bEmptyJunk and internalState.bLiveGUI then
+    cmdUrl = string.format(globals.strCmdEmptyTrashLive, internalState.strMailServer)
+    local post = string.format(globals.strCmdEmptyTrashLivePost, internalState.strJunkId)
+    log.dbg("Sending Empty Junk URL: " .. cmdUrl .."\n")
+    local body, err = browser:post_uri(cmdUrl, post)
+    if not body or err then
+      log.error_print("Error when trying to empty the junk folder with url: ".. cmdUrl .."\n")
+    end
   end
 
   -- Should we force a logout.  If this session runs for more than a day, things
@@ -957,6 +1112,82 @@ function quit_update(pstate)
   return POPSERVER_ERR_OK
 end
 
+-- Stat command for the live gui
+--
+function LiveStat(pstate) 
+  -- Local variables
+  -- 
+  local browser = internalState.browser
+  local nMsgs = 0
+  local nTotMsgs = 0;
+  local nMaxMsgs = 999 
+  if internalState.statLimit ~= nil then
+    nMaxMsgs = internalState.statLimit
+  end  
+
+  local cmdUrl = string.format(globals.strCmdMsgListLive, internalState.strMailServer,
+    internalState.strCrumb)
+  local post = string.format(globals.strCmdMsgListPostLive, internalState.strMBox, nMaxMsgs, nMaxMsgs)
+
+  -- Debug Message
+  --
+  log.dbg("Stat URL: " .. cmdUrl .. "\n");
+		
+  -- Initialize our state
+  --
+  set_popstate_nummesg(pstate, nMsgs)
+
+  -- Iterate over the messages
+  --
+  local body, err = browser:post_uri(cmdUrl, post)
+
+  -- Let's make sure the session is still valid
+  --
+  local _, _, strSessExpr = string.find(body, globals.strRetLoginSessionExpiredLive)
+  if strSessExpr == nil then
+    -- Invalidate the session
+    --
+    internalState.bLoginDone = nil
+    session.remove(hash())
+    log.raw("Session Expired - Last page loaded: " .. cmdUrl .. ", Body: " .. body)
+
+    -- Try Logging back in
+    --
+    local status = loginHotmail()
+    if status ~= POPSERVER_ERR_OK then
+      return POPSERVER_ERR_NETWORK
+    end
+	
+    -- Reset the local variables		
+    --
+    browser = internalState.browser
+    cmdUrl = string.format(globals.strCmdMsgListLive, internalState.strMailServer,
+      internalState.strCrumb)
+
+    -- Retry to load the page
+    --
+    body, err = browser:get_uri(cmdUrl)
+  end
+
+  -- Go through the list of messages
+  --
+  for uidl, size in string.gfind(body, globals.strMsgLivePattern) do
+    nMsgs = nMsgs + 1
+    log.dbg("Processed STAT - Msg: " .. nMsgs .. ", UIDL: " .. uidl .. ", Size: " .. size)
+    set_popstate_nummesg(pstate, nMsgs)
+    set_mailmessage_size(pstate, nMsgs, size)
+    set_mailmessage_uidl(pstate, nMsgs, uidl)
+  end
+
+  -- Update our state
+  --
+  internalState.bStatDone = true
+
+  -- Function completed successfully
+  --
+  return POPSERVER_ERR_OK
+end
+
 -- Stat command - Get the number of messages and their size
 --
 function stat(pstate)
@@ -967,6 +1198,10 @@ function stat(pstate)
     return POPSERVER_ERR_OK
   end
 
+  if internalState.bLiveGUI then
+    return LiveStat(pstate)
+  end
+
   -- Local variables
   -- 
   local browser = internalState.browser
@@ -1267,27 +1502,19 @@ function init(pstate)
 
   -- Serialization
   --
-  if freepops.dofile("serialize.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end 
+  require("serial")
 
   -- Browser
   --
-  if freepops.dofile("browser.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("browser")
 	
   -- MIME Parser/Generator
   --
-  if freepops.dofile("mimer.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end	
+  require("mimer")
 
   -- Common module
   --
-  if freepops.dofile("common.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("common")
 	
   -- Run a sanity check
   --
