@@ -7,9 +7,9 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.8e"
+PLUGIN_VERSION = "0.0.9b"
 PLUGIN_NAME = "juno.com"
-PLUGIN_REQUIRE_VERSION = "0.0.27"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org/download.php?file=juno.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
@@ -29,6 +29,12 @@ Trash. For user defined folders, use their name as the value.]]
 	{name = "emptytrash", description = {
 		en = [[
 Parameter is used to force the plugin to empty the trash when it is done
+pulling messages.]]
+		}	
+	},
+	{name = "resetheaders", description = {
+		en = [[
+Parameter is used to force the plugin to turn off full headers when it is done
 pulling messages.]]
 		}	
 	},
@@ -67,7 +73,7 @@ local globals = {
 
   -- Extract the mail server
   --
-  strMailServerPattern = '/([67].*)$',
+  strMailServerPattern = '/([567].*)$',
 
   -- Pattern to determine if we have no messages
   --
@@ -97,7 +103,7 @@ local globals = {
 
   -- Command URLS
   --
-  strCmdMsgList = "%s/7?folder=%s&sortby=date&direction=up",
+  strCmdMsgList = "%s/7?folder=%s",
   strCmdMsgView = "%s/8?msgNum=%s&folder=%s",
   strCmdDelete = "%s/7?folder=%s&command=delete&msgList=", 
   strCmdReadOptions = "%s/48",
@@ -120,6 +126,7 @@ internalState = {
   strCrumb = nil,
   strMBox = nil,
   bEmptyTrash = false,
+  bResetHeaders = false,
 }
 
 -- ************************************************************************** --
@@ -144,12 +151,13 @@ function serialize_state()
 end
 
 -- -------------------------------------------------------------------------- --
--- Computes the hash of our state.  Concate the user, domain and mailbox.
+-- Computes the hash of our state.  Concate the user, domain, mailbox and password
 --
 function hash()
   return (internalState.strUser or "") .. "~" ..
          (internalState.strDomain or "") .. "~"  ..
-         (internalState.strMBox or "")
+         (internalState.strMBox or "") .. "~"  ..
+	 internalState.strPassword -- this asserts strPassword ~= nil
 end
 
 
@@ -253,8 +261,8 @@ function login()
 	
   -- Debug info
   --
-  log.dbg("Created session (ID: " .. hash() .. ", User: " .. 
-    internalState.strUser .. "@" .. internalState.strDomain .. ")\n")
+  log.dbg("Created session for " .. 
+    internalState.strUser .. "@" .. internalState.strDomain .. "\n")
 
   -- Return Success
   --
@@ -354,9 +362,9 @@ function downloadMsg(pstate, msg, nLines, data)
     
   -- Pipe this through the mimer
   --
-  _, _, str = string.find(cbInfo.strBody, "(<[Hh][Tt][Mm][Ll]>)")
+  --_, _, str = string.find(cbInfo.strBody, "(<[Hh][Tt][Mm][Ll]>)")
   local strBody, strHtml
-  if str ~= nil then
+  if str == nil then
     strBody = nil
     strHtml = cbInfo.strBody
   else
@@ -573,8 +581,10 @@ function getAttachmentTable(cbInfo, data)
     if (filename == "Message") then
       filename = "Message.htm"
     end
+    url = internalState.strMailServer .. "/" .. url
+    filename = getFilename(url, filename)
     log.dbg("Found Attachment, File: " .. filename .. " - Url: " .. url)
-    attachments[filename] = internalState.strMailServer .. "/" .. url
+    attachments[filename] = url
     table.setn(attachments, table.getn(attachments) + 1)
   end
   
@@ -590,7 +600,6 @@ function findInlineAttachments(attachments, cbInfo)
   local cnt = 0
 
   -- Find inline images and sounds
-  --
   for url in string.gfind(body, [[[Ss][Rr][Cc]="(8[^"]+)"]]) do
     attachurl = internalState.strMailServer .. "/" .. url
     filename = "juno_attach_" .. cnt .. "." .. getExtension(attachurl)
@@ -697,6 +706,25 @@ function getContentType(url)
   return (x or "unknown/unknown")
 end
 
+function getFilename(url, filename)
+  local browser = internalState.browser
+  if (string.find(filename, "%.%.%.$") == nil) then
+    return filename
+  end
+
+  local h, err = browser:get_head(url, {}, true)
+  if (err ~= nil) then
+    log.dbg(err)
+    return filename
+  end
+
+  local _, _, x = string.find(h, 'filename= "([^"]+)"')
+  if (x == nil) then
+    return filename
+  end
+  return x
+end
+
 -- ************************************************************************** --
 --  Pop3 functions that must be defined
 -- ************************************************************************** --
@@ -733,6 +761,14 @@ function user(pstate, username)
     internalState.bEmptyTrash = true
   end
 
+  -- Should the trash be emptied at the end of the session?
+  --
+  local val = (freepops.MODULE_ARGS or {}).resetheaders or 0
+  if val == "1" then
+    log.dbg("Juno/Netzero: The full header option will be turn off on quit.")
+    internalState.bResetHeaders = true
+  end
+
   return POPSERVER_ERR_OK
 end
 
@@ -860,6 +896,15 @@ function quit_update(pstate)
     local body, err = browser:get_uri(cmdUrl)
   end
 
+  -- Turn off full headers
+  --
+  if internalState.bResetHeaders == true then
+    cmdUrl = string.format(globals.strCmdReadOptions, internalState.strMailServer)
+    log.dbg("Turning off full headers with URL: " .. cmdUrl .. "\n")
+    local postdata = "headers=0&command=save&page=5"
+    local body, err = browser:post_uri(cmdUrl, postdata)
+  end
+
   -- Save and then Free up the session
   --
   session.save(hash(), serialize_state(), session.OVERWRITE)
@@ -1125,27 +1170,19 @@ function init(pstate)
 
   -- Serialization
   --
-  if freepops.dofile("serialize.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end 
+  require("serial")
 
   -- Browser
   --
-  if freepops.dofile("browser.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("browser")
 	
   -- MIME Parser/Generator
   --
-  if freepops.dofile("mimer.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end	
+  require("mimer")
 
   -- Common module
   --
-  if freepops.dofile("common.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("common")
 	
   -- Run a sanity check
   --
