@@ -1,19 +1,19 @@
 -- ************************************************************************** --
 --  FreePOPs kernel.org changelog plugin
 --  
---  $Id: kernel.lua,v 1.11 2004/12/26 13:07:00 simone_vellei Exp $
+--  $Id: kernel.lua,v 1.15 2006/01/26 01:39:18 russell822 Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Simone Vellei <simone_vellei@users.sourceforge.net>
 -- ************************************************************************** --
 
 -- these are used in the init function
-PLUGIN_VERSION = "0.0.2"
+PLUGIN_VERSION = "0.0.3"
 PLUGIN_NAME = "kernel.org Changelog viewer"
-PLUGIN_REQUIRE_VERSION = "0.0.14"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=kernel.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=kernel.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Simone Vellei"}
 PLUGIN_AUTHORS_CONTACTS = {"simone_vellei (at) users (.) sourceforge (.) net"}
 PLUGIN_DOMAINS = {"@kernel.org","@kernel.org.24","@kernel.org.26"}
@@ -23,11 +23,11 @@ PLUGIN_DESCRIPTIONS = {
 Questo &egrave; un plugin specializzato per tenersi
 aggiornati sulle ultime versioni
 del kernel Linux. La pagina ufficiale che pubblica la lista delle versioni
-correnti del kernel Linux  http://kernel.org. Esiste un metodo comune,
+correnti del kernel Linux &egrave; http://kernel.org. Esiste un metodo comune,
 per i progetti sviluppati in sistemi GNU, per aggiornare l' utente 
 sulle modifiche effettuate nelle nuove versioni di un programma. 
 In ogni pacchetto &egrave; infatti presente il file ChangeLog che descrive le 
-novit apportate dagli autori. Anche
+novit&agrave; apportate dagli autori. Anche
 il kernel Linux ha un ChangeLog per ogni versione nuova. Se desideri essere
 aggior nato sulle novit&agrave; apportate nelle versioni del kernel e,
 quindi, visionare il
@@ -439,14 +439,10 @@ function init(pstate)
 		PLUGIN_NAME.."' version '"..PLUGIN_VERSION.."' started!\n")
 
 	-- the browser module
-	if freepops.dofile("browser.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("browser")
 	
 	-- the common implementation module
-	if freepops.dofile("common.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("common")
 	
 	-- checks on globals
 	freepops.set_sanity_checks()
