@@ -17,7 +17,7 @@
 -- ************************************************************************** --
 --  FreePOPs @libero.it, @inwind.it, @blu.it, @iol.it webmail interface
 --  
---  $Id: libero.lua,v 1.46 2005/10/24 22:26:39 alessiofender Exp $
+--  $Id: libero.lua,v 1.50 2006/03/15 12:57:45 alessiofender Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -27,9 +27,9 @@
 -- fill them in the right way
 
 -- single string, all required
-PLUGIN_VERSION = "0.2.5"
+PLUGIN_VERSION = "0.2.6"
 PLUGIN_NAME = "Libero.IT"
-PLUGIN_REQUIRE_VERSION = "0.0.14"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org/download.php?file=libero.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
@@ -215,10 +215,7 @@ function libero_login()
 
 	-- build the uri
 	local password = internal_state.password
-	local popnumber = math.mod(os.time(),29) + 1  -- == random(1..29)
-        if popnumber == 25 then
-        	popnumber = 24	-- wpop25 doesn't exists
-        end
+	local popnumber = math.mod(os.time(),15) + 1  -- == random(1..15)
 	local domain = internal_state.domain
 	local site = libero_domain[domain].website
 	local choice = libero_domain[domain].choice
@@ -660,20 +657,9 @@ function init(pstate)
 	log.dbg("FreePOPs plugin '"..
 		PLUGIN_NAME.."' version '"..PLUGIN_VERSION.."' started!\n")
 
-	-- the serialization module
-	if freepops.dofile("serialize.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end 
-
-	-- the browser module
-	if freepops.dofile("browser.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
-
-	-- the common implementation module
-	if freepops.dofile("common.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("serial") -- the serialization module
+	require("browser") -- the browser module
+	require("common") -- the common implementation module
 
 	-- checks on globals
 	freepops.set_sanity_checks()
