@@ -7,9 +7,9 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.9d"
+PLUGIN_VERSION = "0.1.00"
 PLUGIN_NAME = "mail.com"
-PLUGIN_REQUIRE_VERSION = "0.0.17"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org/download.php?file=mailcom.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
@@ -70,7 +70,7 @@ PLUGIN_DOMAINS = {"@mail.com","@email.com","@iname.com","@cheerful.com","@consul
 "@webcity.ca","@webmail.lu","@welcomm.ac","@wenxuecity.net","@westham-mail.com","@wimbledon-mail.com",
 "@windrivers.net","@wolves-mail.com","@wongfaye.com","@worldmail.ac","@worldweb.ac","@isleuthmail.com",
 "@x-lab.cc","@xy.com.tw","@yankeeman.com","@yyhmail.com", "@verizonmail.com", "@lycos.com", "@cyberdude.com",
-"@mail.org", "@italymail.com" }
+"@mail.org", "@italymail.com", "@mexico.com" }
 PLUGIN_PARAMETERS = {
 	{name = "folder", description = {
 		en = [[
@@ -122,14 +122,14 @@ local globals = {
   -- Expressions to pull out of returned HTML from mail.com corresponding to a problem
   --
   strRetLoginBadPassword = "(Invalid username[^p]+password.)",
-  strRetLoginSessionExpired = "( [Mm]essage)",
+  strRetLoginSessionExpired = '(onClick="ReportSpam)',
 
   -- Regular expression to extract the mail server
   --
 
   -- Get the mail server for Mail.com
   --
-  strRegExpMailServer = '(http://[^/]*)/scripts',
+  strRegExpMailServer = '(http://[^/]*)/scripts/',
   
   -- Used by Stat to pull out the message ID and the size
   --
@@ -145,6 +145,11 @@ local globals = {
   --
   strInbox = "INBOX",
 
+  -- The amount of time that the session should time out at.
+  -- This is expressed in seconds
+  --
+  nSessionTimeout = 14400,  -- 4 hours!
+
   -- Command URLS
   --
   strCmdOptions = "%s/scripts/mail/options.cgi",
@@ -155,6 +160,7 @@ local globals = {
   strCmdDelete = "%s/scripts/mail/mailbox.mail", 
   strCmdDeletePost = "folder=%s&order=Oldest&changeview=0&mview=a&mstart=1&delete_selected=yes&move_selected=&flag_selected=&flags=&views=a&folder_name=&selectAllBox=off&matchfield=fr&mpat=&",
   strCmdEmptyTrash = "%s/scripts/mail/Outblaze.mail?emptytrash=1&current_folder=Trash",
+  strCmdLogout = "%s/scripts/mail/Outblaze.mail?logout=1&.noframe=1",
 }
 -- ************************************************************************** --
 --  State - Declare the internal state of the plugin.  It will be serialized and remembered.
@@ -172,6 +178,7 @@ internalState = {
   strMBox = nil,
   bEmptyTrash = false,
   bOptionOverride = false,
+  loginTime = nil,
 }
 
 -- ************************************************************************** --
@@ -225,12 +232,13 @@ function serialize_state()
 		internalState.browser:serialize("internalState.browser")
 end
 
--- Computes the hash of our state.  Concate the user, domain and mailbox.
+-- Computes the hash of our state.  Concate the user, domain, mailbox and password
 --
 function hash()
   return (internalState.strUser or "") .. "~" ..
          (internalState.strDomain or "") .. "~"  ..
-         (internalState.strMBox or "")
+         (internalState.strMBox or "") .. "~"  ..
+	 internalState.strPassword -- this asserts strPassword ~= nil
 end
 
 function postToLoginPage(browser, url, post, attempt)
@@ -291,10 +299,11 @@ function login()
   local url = "";
   local post = string.format(globals.strLoginPostData, username, domain, password, domain)
 
-  if (domain == "email.com" or domain == "iname.com") then
+  if (domain == "email.com" or domain == "iname.com" or domain ==  
+"mail.org") then
     url = string.format(globals.strLoginPage, "www", "mail.com")
-  elseif (domain == "usa.com") then
-    url = string.format(globals.strLoginPage, "mail", "usa.com")
+  elseif (domain == "usa.com" or domain == "mexico.com") then
+    url = string.format(globals.strLoginPage, "mail", domain)
   elseif (domain == "lycos.com") then
     url = string.format(globals.strLoginPage3, "mail", "lycos.com")
   elseif (domain == "otakumail.com") then
@@ -341,8 +350,12 @@ function login()
 	
   -- Debug info
   --
-  log.dbg("Created session (ID: " .. hash() .. ", User: " .. 
-    internalState.strUser .. "@" .. internalState.strDomain .. ")\n")
+  log.dbg("Created session for " .. 
+    internalState.strUser .. "@" .. internalState.strDomain .. "\n")
+
+  -- Note the time when we logged in
+  --
+  internalState.loginTime = os.clock();
 
   -- Return Success
   --
@@ -487,12 +500,13 @@ function cleanupHeaders(headers)
     return nil
   end  
 
+  headers = string.gsub(headers, "<script[^>]+>(.*)</script>", "")
   headers = string.gsub(headers, "<!%-%-.-%-%->", "")
   headers = string.gsub(headers, "<!%-%-.*$", "")
   headers = string.gsub(headers, "\n", "")
+  headers = string.gsub(headers, "\t<", "<")
   headers = string.gsub(headers, "\t", " ")
   headers = string.gsub(headers, "<[Ss][Ee][Ll][Ee][Cc][Tt][^>]+>(.-)</[Ss][Ee][Ll][Ee][Cc][Tt]>", "")
-  headers = string.gsub(headers, "<script[^>]+>(.-)</script>", "")
   headers = string.gsub(headers, "</td></tr>", "\n")
   headers = string.gsub(headers, "<[bB][Rr]>", "\n")
   headers = string.gsub(headers, "<[bB][Rr] />", "\n")
@@ -505,14 +519,18 @@ function cleanupHeaders(headers)
   headers = string.gsub(headers, "To:", "To: ")
   headers = string.gsub(headers, "CC:", "CC: ")
   headers = string.gsub(headers, ";[bB]oundary=", ";\n          boundary=")
+  headers = string.gsub(headers, "var popup=0.+'This message is flagged '%);     }    }","")
   
   -- This part could use some cleanup.  There are usually some links in the 
   -- same line as the From:  line. 
   --
+  headers = string.gsub(headers, "%[Save address | Block sender | This Is Spam%]", "\n")
   headers = string.gsub(headers, "%[Save address | Block sender%]", "\n")  
   headers = string.gsub(headers, "%[Save Address%]%[Block Sender%]", "\n")  
   headers = string.gsub(headers, "Save Address Block Sender ", "\n")  
   headers = string.gsub(headers, "%[This Is Spam%]\n", "")
+  headers = string.gsub(headers, "Block Sender", "")
+  headers = string.gsub(headers, "Save Address", "")
   headers = string.gsub(headers, "This Is Spam", "")
   headers = string.gsub(headers, "Previous | Next", "")  
   headers = string.gsub(headers, "\n\n", "\n")
@@ -668,6 +686,25 @@ function quit_update(pstate)
     local body, err = browser:get_uri(cmdUrl)
   end
 
+  -- Should we force a logout.  If this session runs for more than a day, things
+  -- stop working
+  --
+  local currTime = os.clock()
+  local diff = currTime - internalState.loginTime
+  if diff > globals.nSessionTimeout then 
+    cmdUrl = string.format(globals.strCmdLogout, internalState.strMailServer)
+    log.dbg("Sending Logout URL: " .. cmdUrl .. "\n")
+    local body, err = getPage(browser, cmdUrl)
+ 
+    log.dbg("Logout forced to keep mail.com session fresh and tasty!  Yum!\n")
+    log.dbg("Session removed - Account: " .. internalState.strUser .. 
+      "@" .. internalState.strDomain .. "\n")
+    log.raw("Session removed (Forced by mail.com timer) - Account: " .. internalState.strUser .. 
+      "@" .. internalState.strDomain) 
+    session.remove(hash())
+    return POPSERVER_ERR_OK
+  end
+
   -- Save and then Free up the session
   --
   session.save(hash(), serialize_state(), session.OVERWRITE)
@@ -910,27 +947,19 @@ function init(pstate)
 
   -- Serialization
   --
-  if freepops.dofile("serialize.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end 
+  require("serial")
 
   -- Browser
   --
-  if freepops.dofile("browser.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("browser")
 	
   -- MIME Parser/Generator
   --
-  if freepops.dofile("mimer.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end	
+  require("mimer")
 
   -- Common module
   --
-  if freepops.dofile("common.lua") == nil then 
-    return POPSERVER_ERR_UNKNOWN 
-  end
+  require("common")
 	
   -- Run a sanity check
   --
