@@ -1,7 +1,7 @@
 -- ************************************************************************** --
 --  FreePOPs pop3 forwarding plugin
 -- 
---  $Id: popforward.lua,v 1.16 2004/10/31 17:28:03 gareuselesinge Exp $
+--  $Id: popforward.lua,v 1.18 2006/01/26 10:41:37 gareuselesinge Exp $
 -- 
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -13,10 +13,10 @@
 
 PLUGIN_VERSION = "0.0.3"
 PLUGIN_NAME = "POPforward"
-PLUGIN_REQUIRE_VERSION = "0.0.15"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=popforward.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=popforward.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Enrico Tassi"}
 PLUGIN_AUTHORS_CONTACTS = {"gareuselesinge (at) users (.) sourceforge (.) net"}
 PLUGIN_DOMAINS = {"@..."}
