@@ -1,19 +1,19 @@
 -- ************************************************************************** --
 --  FreePOPs @squirrelmail webmail interface
 --  
---  $Id: squirrelmail.lua,v 1.6 2004/09/14 17:08:15 gareuselesinge Exp $
+--  $Id: squirrelmail.lua,v 1.9 2006/01/26 01:39:18 russell822 Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Eddi De Pieri <dpeddi@users.sourceforge.net>
 -- ************************************************************************** --
 
 -- these are used in the init function
-PLUGIN_VERSION = "0.0.1"
+PLUGIN_VERSION = "0.0.2"
 PLUGIN_NAME = "SquirrelMail"
-PLUGIN_REQUIRE_VERSION = "0.0.14"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=squirrelmail.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=squirrelmail.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Eddi De Pieri"}
 PLUGIN_AUTHORS_CONTACTS = {"dpeddi (at) users (.) sourceforge (.) net"}
 PLUGIN_DOMAINS = {"@..."}
@@ -683,24 +683,16 @@ function init(pstate)
 		PLUGIN_NAME.."' version '"..PLUGIN_VERSION.."' started!\n")
 
 	-- the serialization module
-	if freepops.dofile("serialize.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end 
+	require("serial")
 
 	-- the browser module
-	if freepops.dofile("browser.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("browser")
 	
 	-- the MIME mail generator module
-	if freepops.dofile("mimer.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end	
+	require("mimer")
 
 	-- the common implementation module
-	if freepops.dofile("common.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("common")
 	
 	-- checks on globals
 	freepops.set_sanity_checks()
