@@ -1,22 +1,22 @@
 -- ************************************************************************** --
 --  FreePOPs @virgilio.it, @tin.it webmail interface
 --  
---  $Id: tin.lua,v 1.31 2005/06/03 16:29:22 alessiofender Exp $
+--  $Id: tin.lua,v 1.55 2006/06/10 15:59:19 alessiofender Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
 -- ************************************************************************** --
 
 -- these are used in the init function
-PLUGIN_VERSION = "0.0.5"
+PLUGIN_VERSION = "0.0.97"
 PLUGIN_NAME = "Tin.IT"
-PLUGIN_REQUIRE_VERSION = "0.0.14"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org/download.php?file=tin.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Enrico Tassi"}
 PLUGIN_AUTHORS_CONTACTS = {"gareuselesinge (at) users (.) sourceforge (.) net"}
-PLUGIN_DOMAINS = {"@tin.it","@virgilio.it"}
+PLUGIN_DOMAINS = {"@tin.it","@virgilio.it","@alice.it","@tim.it"}
 PLUGIN_PARAMETERS = {
 	{name = "folder", description = {
 		it = [[
@@ -30,9 +30,9 @@ cartella Spam: foo@virgilio.it?folder=Spam]],
 }
 PLUGIN_DESCRIPTIONS = {
 	it="Questo plugin vi per mette di leggere le mail che avete "..
-	   "in una mailbox @virgilio.it , @tin.it . Per usare questo "..
-	   "plugin dovete usare il vostro indirizzo email completo "..
-	   "come user name e la vostra password reale come password.",
+	   "in una mailbox @virgilio.it, @tin.it, @alice.it o @tim.it. "..
+	   "Per usare questo plugin dovete usare il vostro indirizzo email "..
+	   "completo come username e la vostra password reale come password.",
 	en="This plugin is for italian users only."
 }
 
@@ -49,52 +49,71 @@ PLUGIN_DESCRIPTIONS = {
 -- expressions), mlex expressions, mlex get expressions.
 -- 
 local tin_string = {
-	tinsso_dxurl="",
-	tinsso_wmail="webmail_IT",
-	-- The uri the browser uses when you click the "login" button
-	login = "http://aaacsc.virgilio.it/piattaformaAAA/controller/"..
-		"AuthenticationServlet",
+	prelogin = "http://communicator.alice.it/asp/a3login.asp",
+	prelogin_post = "a3aid=comhpma&"..
+		"a3afep=http://mail.virgilio.it/mail/home/mail_error.html&"..
+		"USER=%s&DOMAIN=%s&"..
+		"PASS=%s&Act_Login.x=%d&Act_Login.y=%d",
+--	login = "http://aaacsc.virgilio.it/piattaformaAAA/controller/"..
+--		"AuthenticationServlet",
+	login = "http://communicator.alice.it/asp/login.asp",
 	login_post= "a3l=%s&a3p=%s&a3st=VCOMM&"..
 		"a3aid=communicator&a3flag=0&"..
-		"a3ep=http://communicator.virgilio.it/asp/login.asp&"..
-		"a3afep=http://communicator.virgilio.it/asp/login.asp&"..
-		"a3se=http://communicator.virgilio.it/asp/login.asp&"..
-		"a3dcep=http://communicator.virgilio.it/asp/homepage.asp?s=005",
-	homepage="http://communicator.virgilio.it",
-	webmail="http://communicator.virgilio.it/mail/webmail.asp",
-	-- This is the capture to get the session ID from the login-done webpage
-	sessionC = 'LoadFrames%(".*sid=(%w*)%&',
+		"a3ep=http://communicator.alice.it/asp/login.asp&"..
+		"a3afep=http://communicator.alice.it/asp/login.asp&"..
+		"a3se=http://communicator.alice.it/asp/login.asp&"..
+		"a3dcep=http://communicator.alice.it/asp/homepage.asp?s=005",
+	-- domain, email, tincctoken
+	login2 = "http://webmail.communicator.alice.it/"..
+		"cp/ps/Main/login/PreLogin?"..
+		"d=%s&sa=webmail&style=&mail=%s&token=%s",
+	login2C = 'src="(/cp/ps/Mail/EmailList[^"]*)"',
+	login2Ct="&t=([^&]+)",
+	login2Cs="&s=([%d]+)",
 	-- mesage list mlex
-	statE = ".*<tr>.*<td>.*<spacer>.*</td>.*<td>.*<a>.*<img>.*<img>.*<script>.*</script>.*</a>.*</td>.*<td>.*<input>.*</td>.*<td>.*<p>[.*]{b}.*<a>.*</a>.*{/b}[.*]</p>.*</td>.*<td>.*<p>[.*]{b}.*{/b}[.*]</p>.*</td>.*<td>.*<p>[.*]{b}.*<a>.*</A>.*{/b}[.*]</p>.*</td>.*<td>.*<p>[.*]{b}.*[KkMm]?[Bb]?{/b}[.*]</p>.*</td>.*</tr>",
-	statG = "O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<X>O<O>O<O>O<O>[O]{O}O<O>O<O>O{O}[O]<O>O<O>O<O>O<O>[O]{O}O{O}[O]<O>O<O>O<O>O<O>[O]{O}O<O>O<O>O{O}[O]<O>O<O>O<O>O<O>[O]{O}X{O}[O]<O>O<O>O<O>",
+	statE = ".*<tr>.*<td>.*<input>.*</td>.*<td>.*<a>.*<img>.*</a>.*</td>.*<td>.*<a>.*<img>.*</a>.*</td>.*<td>.*<a>.*<img>.*</a>.*</td>.*<td>.*<a.*Email>.*</a>.*</td>.*<td>.*</td>.*<td>.*<a>.*</a>.*</td>.*<td>.*</td>.*</tr>",
+	statG = "O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<X>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>X<O>O<O>",
+	
 	-- The uri for the first page with the list of messages
-	first = "http://%s/mail/MessageList?sid=%s&userid=%s&"..
-		"seq=+Q&auth=+A&srcfolder=%s&chk=1&style=comm4_IT",
-	-- The uri to get the next page of messages
-	next = "http://%s/mail/MessageList?sid=%s&userid=%s&"..
-		"seq=+Q&auth=+A&srcfolder=%s&chk=1&style=comm4_IT&"..
-		"start=%d&end=%d",
-	-- some stuff for the mail list browsing
-	rangeC='\n%s*rng%s*=%s*"(%d+)%-(%d+)"%s*;',
-	totalC='\n%s*var%s*totalpage%s*=%s*(%d+)%s*/%s*page%s*;',
-	stepC="\n%s*var%s*page%s*=%s*(%d+)%s*;",
+	-- parameters all %s except fi that is %d: 
+	--   wherearewe(), folder, domain, username, t, s, fi
+	first = "http://%s/cp/ps/Mail/EmailList?"..
+		"fp=%s&d=%s&an=&u=%s&t=%s&style="..
+		"&l=it&s=%s&fi=%d&sc=&sd=",
+	-- The regex that, if not found, means we are on the last stat page
+	no_next = "href%s*=%s*'/cp/ps/Mail/EmailList[^']*fi=[^']*'>&gt;&gt;",
+	list_href = "href%s*=%s*'/cp/ps/Mail/EmailList",
 	-- The capture to understand if the session ended
 	timeoutC = '(window.parent.location.*/mail/main?.*err=24)',
 	-- The uri to save a message (read download the message)
-	save = "http://%s/mail/MessageDownload?sid=%s&userid=%s&"..
-		"seq=+Q&auth=+A&srcfolder=%s&uid=%s&srch=0&style=comm4_IT",	
+	--   wherearewe(), mailbox, domain, username, username, uidl, t, s
+	save = "http://%s/cp/ps/Mail/Email"..
+		"?sh=&fp=%s&d=%s&sd=&sc=&an=%s&u=%s&"..
+		"uid=%s&t=%s&style=&l=it&s=%s&sl=%d",	
+	save_sl = "http://%s/cp/ps/Mail/Email"..
+		"?sh=&fp=%s&d=%s&sd=&sc=&an=%s&u=%s&"..
+		"uid=&t=%s&style=&l=it&s=%s&sl=%d",	
+	body_start = [[
+</script>	
+			<br>
+			<br>
+          </div>]],
+	body_end = [[</div></td>%s*<td width="5"><spacer type="block" width="5" height="1"></td>%s*<td width="1" bgcolor="#FFFFFF"><spacer type="block" width="1" height="1"></td>%s*</tr>%s*</table>%s*<!%-%-FINE TABELLA LISTING MAIL%-%->]],
+	 attachE = ".*<a.*href='/cp/ps/Mail/ViewAttachment>.*<img>.*</a>",
+	 attachG = "O<X>O<O>X<O>",
 	-- The uri to delete some messages
-	delete = "http://%s/mail/MessageErase",
-	-- The peace of uri you must append to delete to choose the messages 
-	-- to delete
-	delete_post = "sid=%s&userid=%s&"..
-		"seq=+Q&auth=+A&srcfolder=%s&chk=1&style=comm4_IT&",
-	delete_next = "msguid=%s&"
+	--   whearewe(), domain, username, t, s, 
+	delete = "http://%s/cp/ps/Mail/Delete?d=%s&u=%s&t=%s&style=&l=it&s=%s",
+	-- folder, uidl, username
+	delete_post = "fp=%s&uid=%s&dellist=&an=%s",
+	error_title = "<title>An error has occurred</title>",
 }
 
 tin_domains = {
 	["virgilio.it"] = true,
-	["tin.it"] = true
+	["tin.it"] = true,
+	["alice.it"] = true,
+	["tim.it"] = true
 }
 
 -- ************************************************************************** --
@@ -107,12 +126,15 @@ internal_state = {
 	stat_done = false,
 	login_done = false,
 	popserver = nil,
-	session_id = nil,
+	session_id_s = nil,
+	session_id_t = nil,
 	domain = nil,
 	name = nil,
 	password = nil,
 	b = nil,
-	folder="INBOX"
+	folder="INBOX",
+	reverse_lookup = {},
+	list_begin = -1
 }
 
 -- ************************************************************************** --
@@ -207,6 +229,8 @@ end
 --
 function serialize_state()
 	internal_state.stat_done = false;
+	internal_state.reverse_lookup = {}
+	internal_state.list_begin = -1
 	
 	return serial.serialize("internal_state",internal_state) ..
 		internal_state.b:serialize("internal_state.b")
@@ -225,9 +249,81 @@ function key()
 		(internal_state.folder or "")
 end
 
+
+--------------------------------------------------------------------------------
+-- Detect if the page is an error page
+--
+function is_an_error_page(data)
+	local c = string.find(data, tin_string.error_title)
+	if c == nil then
+		return false
+	else
+		return true
+	end
+end
+
 --------------------------------------------------------------------------------
 -- Login to the tin website
 --
+function dec(s, i) 
+	local tmp = base64.decode(s)
+	local rc = {}
+	while tmp ~= nil do
+		local start, stop = string.find(tmp,"|")
+		if start == nil then
+			table.insert(rc,tmp)
+			tmp = nil
+		else
+			
+			table.insert(rc,string.sub(tmp,1,start-1))
+			tmp = string.sub(tmp,stop+1,-1)
+		end
+	end
+	return rc[i]
+end
+
+function hex2ascii(s)
+	local tab = {
+		["0"]=0;  ["1"]=1;  ["2"]=2;  ["3"]=3;
+		["4"]=4;  ["5"]=5;  ["6"]=6;  ["7"]=7;
+		["8"]=8;  ["9"]=9;  ["A"]=10; ["B"]=11;
+		["C"]=12; ["D"]=13; ["E"]=14; ["F"]=15
+	}
+	s = string.upper(s)
+	local rc = {}
+	local i=1
+	while i <= string.len(s) do
+		local a = tab[string.char(string.byte(s,i))]
+		local b = tab[string.char(string.byte(s,i+1))]
+		if a == nil or b == nil then
+			log.error_print("invalid hex")
+			return ""
+		end
+		table.insert(rc,string.char(a*16+b))
+		i = i + 2
+	end
+	return table.concat(rc)
+end
+
+function geta3p(b, email)
+	local url, post = nil,nil
+	
+	local CPTX = b:get_cookie("CPTX")
+	if CPTX == nil then
+		log.error_print("unable to get CPTX")
+		return nil
+	else
+		local sCPTX = curl.unescape(CPTX.value)
+		sCPTX = hex2ascii(sCPTX)
+		local a3p = dec(sCPTX,2);
+		url = "http://aaacsc.virgilio.it/piattaformaAAA/controller/AuthenticationServlet"
+		post=string.format("a3l=%s&a3p=%s&a3si=-1&percmig=100&a3st=VCOMM&a3aid=comhpma&a3flag=0&a3ep=http://communicator.alice.it/asp/login.asp&a3afep=http://communicator.alice.it/asp/login.asp&a3se=http://communicator.alice.it/asp/login.asp&a3dcep=http://communicator.alice.it/asp/homepage.asp?s=005",email,a3p)
+	end
+
+	
+	return url, post
+end
+
 function tin_login()
 	if internal_state.login_done then
 		return POPSERVER_ERR_OK
@@ -238,63 +334,68 @@ function tin_login()
 	local domain = internal_state.domain
 	local user = internal_state.name
 	local pop_login = user .. "@" .. domain
-	local uri = tin_string.login
-	local post = string.format(tin_string.login_post,pop_login,password)
-	local txcpiu = aaa_encode(pop_login,password,curl.escape(
-		tin_string.tinsso_dxurl))
-	local txmail = aaa_encode(pop_login,password,tin_string.tinsso_wmail)
-	
-	-- we are really greedy :) gnam! gnam!
-	local bisquit1 = mk_cookie("CPIULOGIN","",nil,"/",".virgilio.it",nil)
-	local bisquit2 = mk_cookie("CPTX",txcpiu,nil,"/",".virgilio.it",nil)
-	local bisquit3 = mk_cookie("CPWM",txmail,nil,"/",".virgilio.it",nil)
-	local bisquit4 = mk_cookie("PHXID","",nil,"/",".virgilio.it",nil)
-	local bisquit5 = mk_cookie("PHXPAGE","",nil,"/",".virgilio.it",nil)
 	
 	-- the browser must be preserved
 	internal_state.b = browser.new()
 
 	local b = internal_state.b
--- 	b:verbose_mode()
+ 	--b:verbose_mode()
 
-	b:add_cookie(tin_string.homepage,bisquit3)
-	b:add_cookie(tin_string.homepage,bisquit2)
-	b:add_cookie(tin_string.homepage,bisquit1)
+	-- step 0: create some dummy bisquits and fetch some
+	local post = string.format(tin_string.prelogin_post,
+		user,domain,password,10,10)
+	local body, err = b:post_uri(tin_string.prelogin,post)
+	if body == nil then
+		log.error_print("Error getting "..
+			tin_string.prelogin..": "..err)
+		return POPSERVER_ERR_AUTH
+	end
+
+	local url, post = geta3p(b, pop_login)
 	
-	local body,err = b:post_uri(uri,post)
-
-	b:add_cookie(tin_string.homepage,bisquit4)
-	b:add_cookie(tin_string.homepage,bisquit5)
+	-- step 1: fetch bisquits
 	
-	local extract_f = support.do_extract(
-		internal_state,"session_id",tin_string.sessionC)
-	local check_f = support.check_fail
-	local retrive_f = support.retry_n(
-		3,support.do_retrive(internal_state.b,tin_string.webmail))
+	local body, err = b:post_uri(url,post)
+	if body == nil then
+		log.error_print("Error getting "..tin_string.login..": "..err)
+		return POPSERVER_ERR_AUTH
+	end
 
-	if not support.do_until(retrive_f,check_f,extract_f) then
+	-- step 2: get session id_s and id_t
+	local tincctoken = assert(b:get_cookie("tincctoken"),
+		"unable to find cookie tincctoken").value
+	local url = string.format(tin_string.login2, domain,
+		curl.escape(pop_login), curl.unescape(tincctoken))
+	local body,err = b:get_uri(url)
+	if body == nil then
+		log.error_print("Error getting "..url..": "..err)
+		return POPSERVER_ERR_AUTH
+	end
+	local _,_, capt = string.find(body, tin_string.login2C)
+	local _,_,t = string.find(capt, tin_string.login2Ct) 
+	local _,_,s = string.find(capt, tin_string.login2Cs) 
+	
+	internal_state.session_id_s = s
+	internal_state.session_id_t = t
+	
+	if internal_state.session_id_s == nil or
+	   internal_state.session_id_t == nil then
 		log.error_print("Login failed\n")
 		return POPSERVER_ERR_AUTH
 	end
 
-	-- check if do_extract has correctly extracted the session ID
-	if internal_state.session_id == nil then
-		log.error_print("Login failed, unable to get session ID\n")
-		return POPSERVER_ERR_AUTH
-	end
-		
 	-- save all the computed data
 	internal_state.login_done = true
 	
 	-- log the creation of a session
 	log.say("Session started for " .. internal_state.name .. "@" .. 
 		internal_state.domain .. 
-		"(" .. internal_state.session_id .. ")\n")
+		"(" .. internal_state.session_id_t .. ", " .. 
+			internal_state.session_id_s .. ")\n")
 
 	return POPSERVER_ERR_OK
 end
-
-
+		
 -- ************************************************************************** --
 --  Tin functions
 -- ************************************************************************** --
@@ -314,8 +415,7 @@ function user(pstate,username)
 	-- save domain and name
 	internal_state.domain = domain
 	internal_state.name = name
-	internal_state.folder = freepops.MODULE_ARGS.folder or
-		"INBOX"
+	internal_state.folder = freepops.MODULE_ARGS.folder or "INBOX"
 	
 	return POPSERVER_ERR_OK
 end
@@ -357,7 +457,8 @@ function pass(pstate,password)
 
 		log.say("Session loaded for " .. internal_state.name .. "@" .. 
 			internal_state.domain .. 
-			"(" .. internal_state.session_id .. ")\n")
+			"(" .. internal_state.session_id_s .. ", " ..
+			internal_state.session_id_t .. ")\n")
 		
 		return POPSERVER_ERR_OK
 	else
@@ -383,36 +484,27 @@ function quit_update(pstate)
 	-- shorten names, not really important
 	local b = internal_state.b
 	local popserver = b:wherearewe()
-	local session_id = internal_state.session_id
+	local session_id_s = internal_state.session_id_s
+	local session_id_t = internal_state.session_id_t
 	local domain = internal_state.domain
 	local user = internal_state.name
 	local pop_login = user .. "@" .. domain
+	local folder = internal_state.folder
 	
-	local uri = string.format(tin_string.delete,popserver)
-	local post = string.format(tin_string.delete_post,
-		session_id,pop_login,internal_state.folder)
-
-	-- here we need the stat, we build the uri and we check if we 
-	-- need to delete something
-	local delete_something = false;
+	local uri = string.format(tin_string.delete, popserver, domain, 
+		user, session_id_t, session_id_s)
 	
 	for i=1,get_popstate_nummesg(pstate) do
 		if get_mailmessage_flag(pstate,i,MAILMESSAGE_DELETE) then
-			post = post .. string.format(tin_string.delete_next,
-				get_mailmessage_uidl(pstate,i))
-			delete_something = true	
-		end
-	end
-
-	if delete_something then
-		-- Build the functions for do_until
-		local extract_f = function(s) return true,nil end
-		local check_f = support.check_fail
-		local retrive_f = support.retry_n(3,support.do_post(b,uri,post))
-
-		if not support.do_until(retrive_f,check_f,extract_f) then
-			log.error_print("Unable to delete messages\n")
-			return POPSERVER_ERR_UNKNOWN
+			local uidl = get_mailmessage_uidl(pstate,i)
+			local post = string.format(tin_string.delete_post,
+				folder, uidl, user)
+			local body, err = b:post_uri(uri, post)
+			print(uri, post)--, body)
+			if body == nil then
+				log.error_print("Error getting "..uri..":"..err)
+				return POPSERVER_ERR_UNKNOWN
+			end
 		end
 	end
 
@@ -425,7 +517,8 @@ function quit_update(pstate)
 
 	log.say("Session saved for " .. internal_state.name .. "@" .. 
 		internal_state.domain .. "(" .. 
-		internal_state.session_id .. ")\n")
+		internal_state.session_id_t .. ", " .. 
+		internal_state.session_id_s .. ")\n")
 
 	return POPSERVER_ERR_OK
 end
@@ -433,14 +526,14 @@ end
 -- -------------------------------------------------------------------------- --
 -- Fill the number of messages and their size
 function stat(pstate)
-
 	-- check if already called
 	if internal_state.stat_done then
 		return POPSERVER_ERR_OK
 	end
-	
+
 	-- shorten names, not really important
-	local session_id = internal_state.session_id
+	local session_id_s = internal_state.session_id_s
+	local session_id_t = internal_state.session_id_t
 	local b = internal_state.b
 	local popserver = b:wherearewe()
 	local domain = internal_state.domain
@@ -449,8 +542,10 @@ function stat(pstate)
 
 	-- this string will contain the uri to get. it may be updated by 
 	-- the check_f function, see later
-	local uri = string.format(tin_string.first,popserver,
-		session_id,curl.escape(pop_login),internal_state.folder)
+	local page = 1
+	local uri = string.format(tin_string.first,
+		b:wherearewe(), internal_state.folder,
+		domain, user, session_id_t, session_id_s, page)
 	
 	-- The action for do_until
 	--
@@ -485,7 +580,7 @@ function stat(pstate)
 			_,_,k = string.find(size,"([Kk][Bb])")
 			_,_,m = string.find(size,"([Mm][Bb])")
 			_,_,size = string.find(size,"([%.%d]+)")
-			_,_,uidl = string.find(uidl,'value="([%d]+)"')
+			_,_,uidl = string.find(uidl,'uid=([%d]+)')
 
 			if not uidl or not size then
 				return nil,"Unable to parse page"
@@ -502,6 +597,7 @@ function stat(pstate)
 			-- set it
 			set_mailmessage_size(pstate,i+nmesg_old,size)
 			set_mailmessage_uidl(pstate,i+nmesg_old,uidl)
+			internal_state.reverse_lookup[uidl] = i+nmesg_old
 		end
 		
 		return true,nil
@@ -509,41 +605,47 @@ function stat(pstate)
 
 	-- check must control if we are not in the last page and 
 	-- eventually change uri to tell retrive_f the next page to retrive
+	local count = 0
+	local how_many_refs = 0
+	local function next_page()
+		page = page + 10
+		uri = string.format(tin_string.first,
+			b:wherearewe(), internal_state.folder,
+			domain, user, session_id_t, session_id_s, page)
+		return false
+	end
 	local function check_f (s) 
-		-- FIXME use the <form> fields instead
-		local _,_,_,to = string.find(s,
-			tin_string.rangeC)
-		local _,_,last = string.find(s,
-			tin_string.totalC)
-		if last == nil or to == nil then
-			error("unable to capture last or to")
-		end
-		--print("$$\n"..s.."$$\n")
-		--print("-->",to,last)
-		if to < last then
-			-- change retrive behaviour
-			local _,_,step = string.find(s,
-				tin_string.stepC)
-			if step == nil then
-				log.error_print("unable to capture step")
-				return true
-			end
-			local start = last - to
-			local end_ = math.max(0,start-step)
-			uri = string.format(tin_string.next,popserver,
-				session_id,curl.escape(pop_login),
-				internal_state.folder,
-				start,end_)
-			-- continue the loop
-			return false
+		local tmp = string.find(s,tin_string.no_next)
+		if tmp ~= nil and count == 0 then
+			return next_page()
 		else
-			return true
+			if count == 0 then
+				-- we are on the last page only if we have seen
+				-- this 3 times
+				for x in string.gfind(s,tin_string.list_href) do
+					how_many_refs = how_many_refs + 1
+				end
+				-- there should be links before and after 
+				-- the list
+				if math.mod(how_many_refs, 2) ~= 0 then
+					log.error_print(
+						"Error in counting list_href")
+					return true
+				end
+				how_many_refs = how_many_refs / 2
+			end
+			count = count + 1
+			if count >= how_many_refs then 
+				return true 
+			else
+				return next_page()
+			end
 		end
 	end
 
 	-- this is simple and uri-dependent
 	local function retrive_f ()  
-		--print("getting "..uri)
+		-- print("getting "..uri)
 		local f,err = b:get_uri(uri)
 		if f == nil then
 			return f,err
@@ -559,13 +661,14 @@ function stat(pstate)
 				return nil,"Session ended,unable to recover"
 			end
 			
-			session_id = internal_state.session_id
+			session_id_s = internal_state.session_id_s
+			session_id_t = internal_state.session_id_t
 			b = internal_state.b
 			-- popserver has not changed
-			
-			uri = string.format(tin_string.first,popserver,
-				session_id,curl.escape(pop_login)
-				,internal_state.folder)
+			page = 1
+			uri = string.format(tin_string.first,
+				internal_state.folder,
+				domain, user, session_id_t, session_id_s, page)
 			return b:get_uri(uri)
 		end
 		
@@ -627,36 +730,149 @@ end
 -- -------------------------------------------------------------------------- --
 -- Get first lines message msg lines, must call 
 -- popserver_callback to send the data
+-- 
+function tin_parse_webmessage(wherearewe, data)
+	local head, body, body_html, attach = nil, nil, nil, {}
+
+	-- extract headers 
+	local headersE = ".*<script>.*var *hd *=</script>.*<br>.*<br>.*</div>"
+	local headersG = "O<O>X<O>O<O>O<O>O<O>"
+	local x = mlex.match(data, headersE, headersG)
+	assert(x:count() > 0,"Unable to mlex "..data )
+	local headers = x:get(0,0)
+	assert(headers ~= nil, "Unable to mlex " .. data)
+	local _, _, head = string.find(headers, 'var%s*hd%s*=%s*"([^"]+)"%s*;')
+	head = string.gsub(head, "\\n\\n", "")
+	head = string.gsub(head, "\\r", "\r")
+	head = string.gsub(head, "\\n", "\n")
+	head = string.gsub(head, "        ", "\t")
+	head = string.gsub(head, "\\&quot;", "\"")
+	head = string.gsub(head, "&lt;", "<")
+	head = string.gsub(head, "&gt;", ">")
+	head = string.gsub(head, "\r([^\n])", 
+		function(capture) return "\r\n" .. capture end)
+	
+	-- locate body
+	local _, begin_body = string.find(data, tin_string.body_start)
+	local end_body, _ = string.find(data, tin_string.body_end)
+
+	-- check if it is a plain text message
+	local found = string.find(head,
+		"[Cc][Oo][Nn][Tt][Ee][Nn][Tt]%-[Tt][Yy][Pp][Ee]%s*:%s*"..
+		"[Tt][Ee][Xx][Tt]/[Pp][Ll][Aa][Ii][Nn]")
+	if found == nil then
+		head = mimer.remove_lines_in_proper_mail_header(head,
+			{"content%-type"})
+		body_html = string.sub(data, begin_body + 1, end_body - 1)
+	else
+		body = string.sub(data, begin_body + 1, end_body - 1)
+                body = string.gsub(body, "^%s+", "")
+                body = string.gsub(body, "%s+$", "")
+		body = string.gsub(body, "<br/>", "\r\n");
+		body = string.gsub(body, "<a href[^>]*>", "");
+		body = string.gsub(body, "</a>", "");
+		body = string.gsub(body, "&lt;", "<")
+		body = string.gsub(body, "&gt;", ">")
+                body = string.gsub(body, "&quot;", "\"")
+                body = string.gsub(body, "&#39;", "'")
+                body = string.gsub(body, "&amp;", "&")
+	end
+	
+	-- extract attachments
+	local x = mlex.match(data, tin_string.attachE, tin_string.attachG) 
+	for i = 1, x:count() do
+		local url = x:get(0,i-1)
+		local name = x:get(1,i-1)
+
+		local _, _, name = string.find(name, "^(.*) %(")
+
+		local _, _, url = string.find(url, 
+			"href%s*=%s*'(/cp/ps/Mail/ViewAttachment[^']*)'")
+		
+		attach[name] = "http://"..wherearewe..url
+		table.setn(attach,table.getn(attach) + 1)
+	end
+	
+	return head, body, body_html, attach
+end
+
+function is_a_list_needed(msg, uidl)
+	-- first retr
+	if internal_state.list_begin == -1 then return true, 1 end
+	
+	local position = internal_state.reverse_lookup[uidl]
+	local delta = position - internal_state.list_begin + 1
+	
+	-- before the begin of the list
+	if delta < 0 then return true, 1 end
+	-- in the following 9 items
+	if delta < 10 then return false, delta end
+	
+	return true, 1
+end
+
+
 function retr(pstate,msg,data)
 	-- we need the stat
 	local st = stat(pstate)
 	if st ~= POPSERVER_ERR_OK then return st end
 	
-	-- the callback
-	local cb = common.retr_cb(data)
-	
 	-- some local stuff
-	local session_id = internal_state.session_id
+	local session_id_t = internal_state.session_id_t
+	local session_id_s = internal_state.session_id_s
 	local b = internal_state.b
 	local popserver = b:wherearewe()
 	local domain = internal_state.domain
 	local user = internal_state.name
 	local pop_login = user .. "@" .. domain
-	
-	-- build the uri
+	local folder = internal_state.folder
 	local uidl = get_mailmessage_uidl(pstate,msg)
-	local uri = string.format(tin_string.save,popserver,
-		session_id,curl.escape(pop_login),internal_state.folder,uidl)
-	
-	-- tell the browser to pipe the uri using cb
-	local f,rc = b:pipe_uri(uri,cb)
 
-	if not f then
+	-- It seems the webmail keeps a status of your current listing
+	-- and allows you to see only the messages that the last listing showed
+	-- so, if needed, we relist. If the mail client asks messages from 
+	-- 1 to n this minimizes network usage... if it goes from n to 1 this
+	-- is a shit.
+	local relist, sl = is_a_list_needed(msg, uidl)
+	if relist then
+		-- we do a list that begins with our message
+		local uri_l = string.format(tin_string.first,
+			b:wherearewe(), internal_state.folder,
+			domain, user, session_id_t, session_id_s, msg)
+		local _,_ = b:get_uri(uri_l)
+		internal_state.list_begin = msg
+	end
+	-- whearewe, mailbox, username, username, uidl, t, s
+	local uri = string.format(tin_string.save,b:wherearewe(),
+		folder, domain, user, user, uidl, session_id_t, session_id_s,sl)
+	
+	-- tell the browser to fetch
+	local head,f,rc = b:get_head_and_body(uri)
+	local found,_,ctype = string.find(head,
+		"[Cc][Oo][Nn][Tt][Ee][Nn][Tt]%-[Tt][Yy][Pp][Ee]%s*:"..
+		"%s*[^;\r]+;%s*[Cc][Hh][Aa][Rr][Ss][Ee][Tt]=\"?([^\"\r]*)")
+	if found == nil then
+		ctype = "iso-8859-1"
+	end
+	
+	if f == nil then
 		log.error_print("Asking for "..uri.."\n")
 		log.error_print(rc.."\n")
 		return POPSERVER_ERR_NETWORK
 	end
+		
+	if is_an_error_page(f) then
+		log.error_print("Asking for "..uri.."\n")
+		log.error_print("Internal plugin error, erroneous uri\n")
+		--b:show()
+		return POPSERVER_ERR_UNKNOWN
+	end
 
+	local wherearewe = b:wherearewe()
+	local head,body,body_html,attach = tin_parse_webmessage(wherearewe, f)
+	local cb = mimer.callback_mangler(common.retr_cb(data))
+	mimer.pipe_msg(head,body,body_html,"http://"..wherearewe,attach,b,cb,nil,ctype)
+		
 	return POPSERVER_ERR_OK
 end
 
@@ -667,22 +883,58 @@ function top(pstate,msg,lines,data)
 	-- we need the stat
 	local st = stat(pstate)
 	if st ~= POPSERVER_ERR_OK then return st end
-
+	
 	-- some local stuff
-	local session_id = internal_state.session_id
+	local session_id_t = internal_state.session_id_t
+	local session_id_s = internal_state.session_id_s
 	local b = internal_state.b
 	local popserver = b:wherearewe()
 	local domain = internal_state.domain
 	local user = internal_state.name
 	local pop_login = user .. "@" .. domain
-	local size = get_mailmessage_size(pstate,msg)
-
-	-- build the uri
+	local folder = internal_state.folder
 	local uidl = get_mailmessage_uidl(pstate,msg)
-	local uri = string.format(tin_string.save,popserver,
-		session_id,curl.escape(pop_login),internal_state.folder,uidl)
+	
+	-- It seems the webmail keeps a status of your current listing
+	-- and allows you to see only the messages that the last listing showed
+	-- so, if needed, we relist. If the mail client asks messages from 
+	-- 1 to n this minimizes network usage... if it goes from n to 1 this
+	-- is a shit.
+	local relist, sl = is_a_list_needed(msg, uidl)
+	if relist then
+		-- we do a list that begins with our message
+		local uri_l = string.format(tin_string.first,
+			b:wherearewe(), internal_state.folder,
+			domain, user, session_id_t, session_id_s, msg)
+		local _,_ = b:get_uri(uri_l)
+		internal_state.list_begin = msg
+	end
+	-- whearewe, mailbox, username, username, uidl, t, s
+	local uri = string.format(tin_string.save,b:wherearewe(),
+		folder, domain, user, user, uidl, session_id_t, session_id_s,sl)
+	
+	-- tell the browser to fetch
+	local head,f,rc = b:get_head_and_body(uri)
+	local found,_,ctype = string.find(head,
+		"[Cc][Oo][Nn][Tt][Ee][Nn][Tt]%-[Tt][Yy][Pp][Ee]%s*:"..
+		"%s*[^;\r]+;%s*[Cc][Hh][Aa][Rr][Ss][Ee][Tt]=\"?([^\"\r]*)")
+	if found == nil then
+		ctype = "iso-8859-1"
+	end
+	
+	if f == nil then
+		log.error_print("Asking for "..uri.."\n")
+		log.error_print(rc.."\n")
+		return POPSERVER_ERR_NETWORK
+	end
 
-	return common.top(b,uri,key(),size,lines,data,true)
+	local wherearewe = b:wherearewe()
+	local head,body,body_html,attach = tin_parse_webmessage(wherearewe, f)
+	local global = common.new_global_for_top(lines,nil)
+	local cb = mimer.callback_mangler(common.top_cb(global,data,true))
+	mimer.pipe_msg(head,body,body_html,"http://"..wherearewe,attach,b,cb,nil,ctype)
+		
+	return POPSERVER_ERR_OK
 end
 
 -- -------------------------------------------------------------------------- --
@@ -700,19 +952,16 @@ function init(pstate)
 		PLUGIN_NAME.."' version '"..PLUGIN_VERSION.."' started!\n")
 
 	-- the serialization module
-	if freepops.dofile("serialize.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end 
+	require("serial")
 
 	-- the browser module
-	if freepops.dofile("browser.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("browser")
 
 	-- the common implementation module
-	if freepops.dofile("common.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("common")
+	
+	-- the mimer module
+	require("mimer")
 	
 	-- checks on globals
 	freepops.set_sanity_checks()
