@@ -1,7 +1,7 @@
 -- ************************************************************************** --
 --  FreePOPs @tre.it webmail interface
 --  
---  $Id: tre.lua,v 1.13 2005/01/06 16:21:57 dpeddi Exp $
+--  $Id: tre.lua,v 1.16 2006/01/26 10:41:37 gareuselesinge Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Eddi De Pieri <dpeddi@users.sourceforge.net>
@@ -10,10 +10,10 @@
 -- these are used in the init function
 PLUGIN_VERSION = "0.0.3"
 PLUGIN_NAME = "Tre"
-PLUGIN_REQUIRE_VERSION = "0.0.22"
+PLUGIN_REQUIRE_VERSION = "0.0.97"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=tre.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=tre.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Eddi De Pieri"}
 PLUGIN_AUTHORS_CONTACTS = {"dpeddi (at) users (.) sourceforge (.) net"}
 PLUGIN_DOMAINS = {"@tre.it", "@three.com.au"} 
@@ -783,24 +783,16 @@ function init(pstate)
 		PLUGIN_NAME.."' version '"..PLUGIN_VERSION.."' started!\n")
 
 	-- the serialization module
-	if freepops.dofile("serialize.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end 
+	require("serial")
 
 	-- the browser module
-	if freepops.dofile("browser.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("browser")
 	
 	-- the MIME mail generator module
-	if freepops.dofile("mimer.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end	
+	require("mimer")
 
 	-- the common implementation module
-	if freepops.dofile("common.lua") == nil then 
-		return POPSERVER_ERR_UNKNOWN 
-	end
+	require("common")
 	
 	-- checks on globals
 	freepops.set_sanity_checks()
